@@ -36,20 +36,23 @@
 #include <kstdguiitem.h>
 #include <klineedit.h>
 #include <knuminput.h>
+#include <knuminput.h>
+#include <klineedit.h>
 #include <KToolInvocation>
 
 // ----------------------------------------------------------------------------
 // Project Includes
 
-#include <register.h>
-#include <transactionform.h>
-#include <transaction.h>
-#include <transactioneditor.h>
-#include <kmymoneylineedit.h>
-#include <kmymoneydateinput.h>
-#include <kmymoneymvccombo.h>
-#include <kguiutils.h>
-#include <kmymoneyutils.h>
+#include "register.h"
+#include "transactionform.h"
+#include "transaction.h"
+#include "transactioneditor.h"
+#include "kmymoneylineedit.h"
+#include "kmymoneydateinput.h"
+#include "kmymoneymvccombo.h"
+#include "kguiutils.h"
+#include "kmymoneyutils.h"
+#include "kmymoneydateinput.h"
 
 #include "kmymoney.h"
 
@@ -128,15 +131,15 @@ KEditScheduleDlg::KEditScheduleDlg(const MyMoneySchedule& schedule, QWidget *par
   m_paymentMethodEdit->setCurrentItem(method);
 
   switch (d->m_schedule.weekendOption()) {
-  case MyMoneySchedule::MoveNothing:
-    m_weekendOptionEdit->setCurrentIndex(0);
-    break;
-  case MyMoneySchedule::MoveBefore:
-    m_weekendOptionEdit->setCurrentIndex(1);
-    break;
-  case MyMoneySchedule::MoveAfter:
-    m_weekendOptionEdit->setCurrentIndex(2);
-    break;
+    case MyMoneySchedule::MoveNothing:
+      m_weekendOptionEdit->setCurrentIndex(0);
+      break;
+    case MyMoneySchedule::MoveBefore:
+      m_weekendOptionEdit->setCurrentIndex(1);
+      break;
+    case MyMoneySchedule::MoveAfter:
+      m_weekendOptionEdit->setCurrentIndex(2);
+      break;
   }
   m_estimateEdit->setChecked(!d->m_schedule.isFixed());
   m_autoEnterEdit->setChecked(d->m_schedule.autoEnter());
@@ -210,40 +213,40 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     d->m_tabOrderWidgets.clear();
     KMyMoneyRegister::Action action = KMyMoneyRegister::ActionWithdrawal;
     switch (d->m_schedule.type()) {
-    case MyMoneySchedule::TYPE_DEPOSIT:
-      action = KMyMoneyRegister::ActionDeposit;
-      break;
-    case MyMoneySchedule::TYPE_BILL:
-      action = KMyMoneyRegister::ActionWithdrawal;
-      break;
-    case MyMoneySchedule::TYPE_TRANSFER:
-      action = KMyMoneyRegister::ActionTransfer;
-      break;
-    default:
-      // if we end up here, we don't have a known schedule type (yet). in this case, we just glimpse
-      // into the transaction and determine the type. in case we don't have a transaction with splits
-      // we stick with the default action already set up
-      if (d->m_schedule.transaction().splits().count() > 0) {
-        QList<MyMoneySplit>::const_iterator it_s;
-        bool isDeposit = false;
-        bool isTransfer = false;
-        for (it_s = d->m_schedule.transaction().splits().begin(); it_s != d->m_schedule.transaction().splits().end(); ++it_s) {
-          if ((*it_s).accountId() == d->m_schedule.account().id()) {
-            isDeposit = !((*it_s).shares().isNegative());
-          } else {
-            MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
-            if (acc.isAssetLiability() && d->m_schedule.transaction().splits().count() == 2) {
-              isTransfer = true;
+      case MyMoneySchedule::TYPE_DEPOSIT:
+        action = KMyMoneyRegister::ActionDeposit;
+        break;
+      case MyMoneySchedule::TYPE_BILL:
+        action = KMyMoneyRegister::ActionWithdrawal;
+        break;
+      case MyMoneySchedule::TYPE_TRANSFER:
+        action = KMyMoneyRegister::ActionTransfer;
+        break;
+      default:
+        // if we end up here, we don't have a known schedule type (yet). in this case, we just glimpse
+        // into the transaction and determine the type. in case we don't have a transaction with splits
+        // we stick with the default action already set up
+        if (d->m_schedule.transaction().splits().count() > 0) {
+          QList<MyMoneySplit>::const_iterator it_s;
+          bool isDeposit = false;
+          bool isTransfer = false;
+          for (it_s = d->m_schedule.transaction().splits().begin(); it_s != d->m_schedule.transaction().splits().end(); ++it_s) {
+            if ((*it_s).accountId() == d->m_schedule.account().id()) {
+              isDeposit = !((*it_s).shares().isNegative());
+            } else {
+              MyMoneyAccount acc = MyMoneyFile::instance()->account((*it_s).accountId());
+              if (acc.isAssetLiability() && d->m_schedule.transaction().splits().count() == 2) {
+                isTransfer = true;
+              }
             }
           }
-        }
 
-        if (isTransfer)
-          action = KMyMoneyRegister::ActionTransfer;
-        else if (isDeposit)
-          action = KMyMoneyRegister::ActionDeposit;
-      }
-      break;
+          if (isTransfer)
+            action = KMyMoneyRegister::ActionTransfer;
+          else if (isDeposit)
+            action = KMyMoneyRegister::ActionDeposit;
+        }
+        break;
     }
     editor->setup(d->m_tabOrderWidgets, d->m_schedule.account(), action);
 
@@ -257,7 +260,25 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
 
     Q_ASSERT(!d->m_tabOrderWidgets.isEmpty());
 
+    d->m_tabOrderWidgets.push_front(m_paymentMethodEdit);
+
+    // editor->setup() leaves the tabbar as the last widget in the stack, but we
+    // need it as first here. So we move it around.
+    QWidget* w = editor->haveWidget("tabbar");
+    if (w) {
+      int idx = d->m_tabOrderWidgets.indexOf(w);
+      if (idx != -1) {
+        d->m_tabOrderWidgets.removeAt(idx);
+        d->m_tabOrderWidgets.push_front(w);
+      }
+    }
+
     // don't forget our three buttons and additional widgets
+    // make sure to use the correct order
+    d->m_tabOrderWidgets.push_front(m_frequencyEdit);
+    d->m_tabOrderWidgets.push_front(m_frequencyNoEdit);
+    d->m_tabOrderWidgets.push_front(m_nameEdit);
+
     d->m_tabOrderWidgets.append(m_weekendOptionEdit);
     d->m_tabOrderWidgets.append(m_estimateEdit);
     d->m_tabOrderWidgets.append(m_variation);
@@ -269,11 +290,6 @@ TransactionEditor* KEditScheduleDlg::startEdit(void)
     d->m_tabOrderWidgets.append(buttonOk);
     d->m_tabOrderWidgets.append(buttonCancel);
     d->m_tabOrderWidgets.append(buttonHelp);
-    d->m_tabOrderWidgets.append(m_nameEdit);
-    d->m_tabOrderWidgets.append(m_frequencyNoEdit);
-    d->m_tabOrderWidgets.append(m_frequencyEdit);
-    d->m_tabOrderWidgets.append(m_paymentMethodEdit);
-    d->m_tabOrderWidgets.append(m_form);
     for (int i = 0; i < d->m_tabOrderWidgets.size(); ++i) {
       QWidget* w = d->m_tabOrderWidgets.at(i);
       if (w) {
@@ -339,15 +355,15 @@ const MyMoneySchedule& KEditScheduleDlg::schedule(void) const
     d->m_schedule.setOccurrenceMultiplier(m_frequencyNoEdit->value());
 
     switch (m_weekendOptionEdit->currentIndex())  {
-    case 0:
-      d->m_schedule.setWeekendOption(MyMoneySchedule::MoveNothing);
-      break;
-    case 1:
-      d->m_schedule.setWeekendOption(MyMoneySchedule::MoveBefore);
-      break;
-    case 2:
-      d->m_schedule.setWeekendOption(MyMoneySchedule::MoveAfter);
-      break;
+      case 0:
+        d->m_schedule.setWeekendOption(MyMoneySchedule::MoveNothing);
+        break;
+      case 1:
+        d->m_schedule.setWeekendOption(MyMoneySchedule::MoveBefore);
+        break;
+      case 2:
+        d->m_schedule.setWeekendOption(MyMoneySchedule::MoveAfter);
+        break;
     }
 
     d->m_schedule.setType(MyMoneySchedule::TYPE_BILL);
@@ -355,16 +371,16 @@ const MyMoneySchedule& KEditScheduleDlg::schedule(void) const
     KMyMoneyTransactionForm::TabBar* tabbar = dynamic_cast<KMyMoneyTransactionForm::TabBar*>(d->m_editor->haveWidget("tabbar"));
     if (tabbar) {
       switch (static_cast<KMyMoneyRegister::Action>(tabbar->currentIndex())) {
-      case KMyMoneyRegister::ActionDeposit:
-        d->m_schedule.setType(MyMoneySchedule::TYPE_DEPOSIT);
-        break;
-      default:
-      case KMyMoneyRegister::ActionWithdrawal:
-        d->m_schedule.setType(MyMoneySchedule::TYPE_BILL);
-        break;
-      case KMyMoneyRegister::ActionTransfer:
-        d->m_schedule.setType(MyMoneySchedule::TYPE_TRANSFER);
-        break;
+        case KMyMoneyRegister::ActionDeposit:
+          d->m_schedule.setType(MyMoneySchedule::TYPE_DEPOSIT);
+          break;
+        default:
+        case KMyMoneyRegister::ActionWithdrawal:
+          d->m_schedule.setType(MyMoneySchedule::TYPE_BILL);
+          break;
+        case KMyMoneyRegister::ActionTransfer:
+          d->m_schedule.setType(MyMoneySchedule::TYPE_TRANSFER);
+          break;
       }
     } else {
       qDebug("No tabbar found in KEditScheduleDlg::schedule(). Defaulting type to BILL");
@@ -402,24 +418,29 @@ bool KEditScheduleDlg::focusNextPrevChild(bool next)
   w = qApp->focusWidget();
   int currentWidgetIndex = d->m_tabOrderWidgets.indexOf(w);
   while (w && currentWidgetIndex == -1) {
-    // qDebug("'%s' not in list, use parent", w->className());
+    // qDebug("'%s' not in list, use parent", qPrintable(w->objectName()));
     w = w->parentWidget();
     currentWidgetIndex = d->m_tabOrderWidgets.indexOf(w);
   }
 
   if (currentWidgetIndex != -1) {
-    // if(w) qDebug("tab order is at '%s'", w->className());
-    QWidgetList::const_iterator it = d->m_tabOrderWidgets.constBegin() + currentWidgetIndex;
-    if (next)
-      w = ((it + 1) != d->m_tabOrderWidgets.constEnd()) ? *(it + 1) : d->m_tabOrderWidgets.first();
-    else
-      w = ((it - 1) != d->m_tabOrderWidgets.constBegin()) ? *(it - 1) : d->m_tabOrderWidgets.last();
+    do {
+      // if(w) qDebug("tab order is at '%s (%d/%d)'", qPrintable(w->objectName()), currentWidgetIndex, d->m_tabOrderWidgets.size());
+      currentWidgetIndex += next ? 1 : -1;
+      if (currentWidgetIndex < 0)
+        currentWidgetIndex = d->m_tabOrderWidgets.size() - 1;
+      else if (currentWidgetIndex >= d->m_tabOrderWidgets.size())
+        currentWidgetIndex = 0;
 
-    if (((w->focusPolicy() & Qt::TabFocus) == Qt::TabFocus) && w->isVisible() && w->isEnabled()) {
-      // qDebug("Selecting '%s' as focus", w->className());
-      w->setFocus();
-      rc = true;
-    }
+      w = d->m_tabOrderWidgets[currentWidgetIndex];
+      // qDebug("currentWidgetIndex = %d, w = %p", currentWidgetIndex, w);
+
+      if (((w->focusPolicy() & Qt::TabFocus) == Qt::TabFocus) && w->isVisible() && w->isEnabled()) {
+        // qDebug("Selecting '%s' as focus", qPrintable(w->objectName()));
+        w->setFocus();
+        rc = true;
+      }
+    } while (rc == false);
   }
   return rc;
 }
@@ -496,19 +517,19 @@ void KEditScheduleDlg::slotFrequencyChanged(int item)
   if (isEndSeries)
     m_endOptionsFrame->setEnabled(item != MyMoneySchedule::OCCUR_ONCE);
   switch (item) {
-  case MyMoneySchedule::OCCUR_DAILY:
-  case MyMoneySchedule::OCCUR_WEEKLY:
-  case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
-  case MyMoneySchedule::OCCUR_MONTHLY:
-  case MyMoneySchedule::OCCUR_YEARLY:
-    // Supports Frequency Number
-    m_frequencyNoEdit->setEnabled(true);
-    break;
-  default:
-    // Multiplier is always 1
-    m_frequencyNoEdit->setEnabled(false);
-    m_frequencyNoEdit->setValue(1);
-    break;
+    case MyMoneySchedule::OCCUR_DAILY:
+    case MyMoneySchedule::OCCUR_WEEKLY:
+    case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
+    case MyMoneySchedule::OCCUR_MONTHLY:
+    case MyMoneySchedule::OCCUR_YEARLY:
+      // Supports Frequency Number
+      m_frequencyNoEdit->setEnabled(true);
+      break;
+    default:
+      // Multiplier is always 1
+      m_frequencyNoEdit->setEnabled(false);
+      m_frequencyNoEdit->setValue(1);
+      break;
   }
   if (isEndSeries && (item != MyMoneySchedule::OCCUR_ONCE)) {
     // Changing the frequency changes the number
