@@ -64,6 +64,8 @@ public:
     for (QStringList::ConstIterator it_l = list.constBegin(); it_l != list.constEnd(); ++it_l) {
       const MyMoneyAccount& acc = m_file->account(*it_l);
 
+      loadInstitution(model, acc);
+
       QStandardItem *item = itemFromAccountId(accountsItem, acc.id());
       if (!item) {
         item = new QStandardItem(acc.name());
@@ -91,7 +93,6 @@ public:
         // set the account data after the children have been loaded
         setAccountData(model, item->index(), acc);
       }
-
     }
   }
 
@@ -133,37 +134,38 @@ public:
 
     QPixmap checkMark = QPixmap(KIconLoader::global()->loadIcon("dialog-ok", KIconLoader::Small));
     switch (account.accountType()) {
-    case MyMoneyAccount::Income:
-    case MyMoneyAccount::Expense:
-    case MyMoneyAccount::Asset:
-    case MyMoneyAccount::Liability:
-      if (account.value("Tax").toLower() == "yes") {
-        // Tax
-        newIndex = model->index(index.row(), index.column() + Tax, index.parent());
-        model->setData(newIndex, checkMark, Qt::DecorationRole);
-      }
-      if (!account.value("VatAccount").isEmpty()) {
-        // VAT
-        newIndex = model->index(index.row(), index.column() + VAT, index.parent());
-        model->setData(newIndex, checkMark, Qt::DecorationRole);
-      }
-      if (!account.value("VatRate").isEmpty()) {
-        MyMoneyMoney vatRate = MyMoneyMoney(account.value("VatRate")) * MyMoneyMoney(100, 1);
-        newIndex = model->index(index.row(), index.column() + VAT, index.parent());
-        model->setData(newIndex, QString("%1 %").arg(vatRate.formatMoney("", 1)), Qt::DisplayRole);
-        model->setData(newIndex, Qt::AlignRight, Qt::TextAlignmentRole);
-      }
-      break;
-    default:
-      break;
+      case MyMoneyAccount::Income:
+      case MyMoneyAccount::Expense:
+      case MyMoneyAccount::Asset:
+      case MyMoneyAccount::Liability:
+        if (account.value("Tax").toLower() == "yes") {
+          // Tax
+          newIndex = model->index(index.row(), index.column() + Tax, index.parent());
+          model->setData(newIndex, checkMark, Qt::DecorationRole);
+        }
+        if (!account.value("VatAccount").isEmpty()) {
+          // VAT
+          newIndex = model->index(index.row(), index.column() + VAT, index.parent());
+          model->setData(newIndex, checkMark, Qt::DecorationRole);
+        }
+        if (!account.value("VatRate").isEmpty()) {
+          MyMoneyMoney vatRate = MyMoneyMoney(account.value("VatRate")) * MyMoneyMoney(100, 1);
+          newIndex = model->index(index.row(), index.column() + VAT, index.parent());
+          model->setData(newIndex, QString("%1 %").arg(vatRate.formatMoney("", 1)), Qt::DisplayRole);
+          model->setData(newIndex, QVariant(Qt::AlignRight | Qt::AlignVCenter), Qt::TextAlignmentRole);
+        }
+        break;
+      default:
+        break;
     }
 
     // Total Balance
     newIndex = model->index(index.row(), index.column() + TotalBalance, index.parent());
     // only show the balance, if its a different security/currency
-    if (m_file->security(account.currencyId()) != m_file->baseCurrency())
+    if (m_file->security(account.currencyId()) != m_file->baseCurrency()) {
       model->setData(newIndex, accountBalance.formatMoney(m_file->security(account.currencyId())), Qt::DisplayRole);
-    model->setData(newIndex, accountBalance.formatMoney(m_file->security(account.currencyId())), AccountBalanceDispalyRole);
+      model->setData(newIndex, accountBalance.formatMoney(m_file->security(account.currencyId())), AccountBalanceDisplayRole);
+    }
     model->setData(newIndex, font, Qt::FontRole);
     model->setData(newIndex, QVariant(Qt::AlignRight | Qt::AlignVCenter), Qt::TextAlignmentRole);
 
@@ -190,14 +192,14 @@ public:
       balance = account.balance();
     // for income and liability accounts, we reverse the sign
     switch (account.accountGroup()) {
-    case MyMoneyAccount::Income:
-    case MyMoneyAccount::Liability:
-    case MyMoneyAccount::Equity:
-      balance = -balance;
-      break;
+      case MyMoneyAccount::Income:
+      case MyMoneyAccount::Liability:
+      case MyMoneyAccount::Equity:
+        balance = -balance;
+        break;
 
-    default:
-      break;
+      default:
+        break;
     }
 
     return balance;
@@ -285,7 +287,7 @@ public:
   /**
     * Function to get the item from an account id.
     *
-    * @param parent The parent to localize the seach in the child items of this parameter.
+    * @param parent The parent to localize the search in the child items of this parameter.
     * @param accountId Search based on this parameter.
     *
     * @return The item corresponding to the given account id, NULL if the account was not found.
@@ -301,7 +303,70 @@ public:
   }
 
   /**
-    * Used to laod the accounts data.
+    * Function to get the institution item from an institution id.
+    *
+    * @param model The model in which to look for the item.
+    * @param institutionId Search based on this parameter.
+    *
+    * @return The item corresponding to the given institution id, NULL if the institution was not found.
+    */
+  QStandardItem *institutionItemFromId(QStandardItemModel *model, const QString &institutionId) {
+    QModelIndexList list = model->match(model->index(0, 0), AccountsModel::AccountIdRole, QVariant(institutionId), 1, Qt::MatchFlags(Qt::MatchExactly | Qt::MatchCaseSensitive));
+    if (list.count() > 0) {
+      return model->itemFromIndex(list.front());
+    }
+    return 0;
+  }
+
+  /**
+    * Function to add the account item to it's corresponding institution item.
+    *
+    * @param model The model where to add the item.
+    * @param account The account for which to create the item.
+    *
+    */
+  void loadInstitution(QStandardItemModel *model, const MyMoneyAccount &account) {
+    if (!account.isAssetLiability() && !account.isInvest())
+      return;
+
+    QFont font;
+    font.setBold(true);
+
+    QString institutionId = account.institutionId();
+    if (account.isInvest()) {
+      MyMoneyAccount parentAccount = m_file->account(account.parentAccountId());
+      institutionId = parentAccount.institutionId();
+    }
+    QStandardItem *institutionItem = institutionItemFromId(model, institutionId);
+    QStandardItem *item = itemFromAccountId(institutionItem, account.id());
+    QStandardItem *parentAccounItem = itemFromAccountId(institutionItem, account.parentAccountId());
+    if (!item) {
+      item = new QStandardItem(account.name());
+      if (parentAccounItem) {
+        parentAccounItem->appendRow(item);
+      } else {
+        institutionItem->appendRow(item);
+      }
+      item->setColumnCount(model->columnCount());
+      item->setEditable(false);
+    }
+    setAccountData(model, item->index(), account);
+    if (parentAccounItem)
+      setAccountData(model, parentAccounItem->index(), m_file->account(account.parentAccountId()));
+    MyMoneyMoney accountTotalValue = item->data(AccountTotalValueRole).value<MyMoneyMoney>();
+    MyMoneyMoney institutionValue = institutionItem->data(AccountTotalValueRole).value<MyMoneyMoney>() + accountTotalValue;
+    institutionItem->setData(QVariant::fromValue(institutionValue), AccountTotalValueRole);
+    institutionItem->setData(false, CleanupRole);
+    QModelIndex instIndex = institutionItem->index();
+    QModelIndex newIndex = model->index(instIndex.row(), instIndex.column() + TotalValue, instIndex.parent());
+    model->setData(newIndex, institutionValue.formatMoney(m_file->baseCurrency()), Qt::DisplayRole);
+    model->setData(newIndex, institutionValue.formatMoney(m_file->baseCurrency()), AccountTotalValueDisplayRole);
+    model->setData(newIndex, font, Qt::FontRole);
+    model->setData(newIndex, QVariant(Qt::AlignRight | Qt::AlignVCenter), Qt::TextAlignmentRole);
+  }
+
+  /**
+    * Used to load the accounts data.
     */
   MyMoneyFile *m_file;
   /**
@@ -329,26 +394,26 @@ AccountsModel::AccountsModel(QObject *parent /*= 0*/)
   QStringList headerLabels;
   for (int i = 0; i < LastColumnMarker; ++i) {
     switch (i) {
-    case Account:
-      headerLabels << i18n("Account");
-      break;
-    case Type:
-      headerLabels << i18n("Type");
-      break;
-    case Tax:
-      headerLabels << i18nc("Column heading for category in tax report", "Tax");
-      break;
-    case VAT:
-      headerLabels << i18nc("Column heading for VAT category", "VAT");
-      break;
-    case TotalBalance:
-      headerLabels << i18n("Total Balance");
-      break;
-    case TotalValue:
-      headerLabels << i18n("Total Value");
-      break;
-    default:
-      headerLabels << QString();
+      case Account:
+        headerLabels << i18n("Account");
+        break;
+      case Type:
+        headerLabels << i18n("Type");
+        break;
+      case Tax:
+        headerLabels << i18nc("Column heading for category in tax report", "Tax");
+        break;
+      case VAT:
+        headerLabels << i18nc("Column heading for VAT category", "VAT");
+        break;
+      case TotalBalance:
+        headerLabels << i18n("Total Balance");
+        break;
+      case TotalValue:
+        headerLabels << i18n("Total Value");
+        break;
+      default:
+        headerLabels << QString();
     }
   }
   setHorizontalHeaderLabels(headerLabels);
@@ -373,6 +438,36 @@ void AccountsModel::load()
 
   QStandardItem *rootItem = invisibleRootItem();
 
+  QFont font;
+  font.setBold(true);
+
+  // Institutions
+  QList<MyMoneyInstitution> institutionList;
+  d->m_file->institutionList(institutionList);
+  MyMoneyInstitution none;
+  none.setName(i18n("Accounts with no institution assigned"));
+  institutionList.append(none);
+  foreach (const MyMoneyInstitution &institution, institutionList) {
+    QStandardItem *institutionItem = d->institutionItemFromId(this, institution.id());
+    if (!institutionItem) {
+      institutionItem = new QStandardItem(institution.name());
+      rootItem->appendRow(institutionItem);
+    }
+    institutionItem->setData(institution.name(), Qt::DisplayRole);
+    institutionItem->setData(QVariant::fromValue(institution), AccountRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountBalanceRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountValueRole);
+    institutionItem->setData(QVariant::fromValue(MyMoneyMoney(0)), AccountTotalValueRole);
+    institutionItem->setData(institution.id(), AccountIdRole);
+    institutionItem->setData(6, DisplayOrderRole);
+    institutionItem->setColumnCount(columnCount());
+    institutionItem->setIcon(institution.pixmap());
+    institutionItem->setFont(font);
+    institutionItem->setEditable(false);
+    // don't remove any real institution but remove 'none' if it does not contain accounts
+    institutionItem->setData(institution.id().isEmpty(), CleanupRole);
+  }
+
   // Favorite accounts
   QStandardItem *favoriteAccountsItem = d->itemFromAccountId(rootItem, favoritesAccountId);
   if (!favoriteAccountsItem) {
@@ -381,12 +476,10 @@ void AccountsModel::load()
     setData(favoriteAccountsItem->index(), favoritesAccountId, AccountIdRole);
     setData(favoriteAccountsItem->index(), 0, DisplayOrderRole);
     favoriteAccountsItem->setColumnCount(columnCount());
-    favoriteAccountsItem->setIcon(QIcon(DesktopIcon("account")));
+    favoriteAccountsItem->setIcon(QIcon(DesktopIcon("account"))); //krazy:exclude=iconnames
     favoriteAccountsItem->setEditable(false);
   }
   setData(favoriteAccountsItem->index(), false, CleanupRole);
-  QFont font = favoriteAccountsItem->font();
-  font.setBold(true);
   favoriteAccountsItem->setFont(font);
 
   for (int mask = 0x01; mask != KMyMoneyUtils::last; mask <<= 1) {
@@ -443,6 +536,9 @@ void AccountsModel::load()
 
     for (QStringList::ConstIterator it_l = list.constBegin(); it_l != list.constEnd(); ++it_l) {
       const MyMoneyAccount& acc = d->m_file->account(*it_l);
+
+      d->loadInstitution(this, acc);
+
       QStandardItem *item = d->itemFromAccountId(accountsItem, acc.id());
       if (!item) {
         item = new QStandardItem(acc.name());
@@ -487,6 +583,8 @@ void AccountsModel::load()
       parentsOnlyList.append(index);
     }
   }
+  // sort the indexes in reverse order so when deleting the rows the rows of the remaining indexes are still valid
+  qSort(parentsOnlyList.begin(), parentsOnlyList.end(), qGreater<QModelIndex>());
   foreach (const QModelIndex &index, parentsOnlyList) {
     removeRow(index.row(), index.parent());
   }
@@ -546,6 +644,11 @@ void AccountsModel::load()
   }
 }
 
+MyMoneyMoney AccountsModel::accountValue(const MyMoneyAccount &account, const MyMoneyMoney &balance)
+{
+  return d->value(account, balance);
+}
+
 /**
   * This slot should be connected so that the model will be notified which account is being reconciled.
   */
@@ -580,6 +683,7 @@ public:
   Private() :
       m_hideClosedAccounts(true),
       m_hideEquityAccounts(true),
+      m_hideInstitutions(true),
       m_hideUnusedIncomeExpenseAccounts(false) {
   }
 
@@ -589,6 +693,7 @@ public:
   QList<MyMoneyAccount::accountTypeE> m_typeList;
   bool m_hideClosedAccounts;
   bool m_hideEquityAccounts;
+  bool m_hideInstitutions;
   bool m_hideUnusedIncomeExpenseAccounts;
   bool m_haveHiddenUnusedIncomeExpenseAccounts;
 };
@@ -677,7 +782,7 @@ void AccountsFilterProxyModel::addAccountGroup(MyMoneyAccount::accountTypeE grou
   } else if (group == MyMoneyAccount::Equity) {
     d->m_typeList << MyMoneyAccount::Equity;
   }
-  invalidateFilter();
+  invalidate();
 }
 
 /**
@@ -688,7 +793,7 @@ void AccountsFilterProxyModel::addAccountGroup(MyMoneyAccount::accountTypeE grou
 void AccountsFilterProxyModel::addAccountType(MyMoneyAccount::accountTypeE type)
 {
   d->m_typeList << type;
-  invalidateFilter();
+  invalidate();
 }
 
 /**
@@ -701,7 +806,7 @@ void AccountsFilterProxyModel::removeAccountType(MyMoneyAccount::accountTypeE ty
   int index = d->m_typeList.indexOf(type);
   if (index != -1) {
     d->m_typeList.removeAt(index);
-    invalidateFilter();
+    invalidate();
   }
 }
 
@@ -711,7 +816,7 @@ void AccountsFilterProxyModel::removeAccountType(MyMoneyAccount::accountTypeE ty
 void AccountsFilterProxyModel::clear(void)
 {
   d->m_typeList.clear();
-  invalidateFilter();
+  invalidate();
 }
 
 /**
@@ -722,29 +827,39 @@ bool AccountsFilterProxyModel::acceptSourceItem(const QModelIndex &source) const
   if (source.isValid()) {
     QVariant data = sourceModel()->data(source, AccountsModel::AccountRole);
     if (data.isValid()) {
-      MyMoneyAccount account = data.value<MyMoneyAccount>();
-      if ((hideClosedAccounts() && account.isClosed()))
-        return false;
-
-      // we hide stock accounts if not in expert mode
-      if (account.isInvest() && hideEquityAccounts())
-        return false;
-
-      // we hide equity accounts if not in expert mode
-      if (account.accountType() == MyMoneyAccount::Equity && hideEquityAccounts())
-        return false;
-
-      // we hide unused income and expense accounts if the specific flag is set
-      if ((account.accountType() == MyMoneyAccount::Income || account.accountType() == MyMoneyAccount::Expense) && hideUnusedIncomeExpenseAccounts()) {
-        QVariant totalValue = sourceModel()->data(source, AccountsModel::AccountTotalValueRole);
-        if (totalValue.isValid() && totalValue.value<MyMoneyMoney>().isZero()) {
-          emit unusedIncomeExpenseAccountHidden();
+      if (data.canConvert<MyMoneyAccount>()) {
+        // hide the account groups when showing the institutions
+        if (!hideInstitutions() && !source.parent().isValid())
           return false;
+
+        MyMoneyAccount account = data.value<MyMoneyAccount>();
+        if ((hideClosedAccounts() && account.isClosed()))
+          return false;
+
+        // we hide stock accounts if not in expert mode
+        if (account.isInvest() && hideEquityAccounts())
+          return false;
+
+        // we hide equity accounts if not in expert mode
+        if (account.accountType() == MyMoneyAccount::Equity && hideEquityAccounts())
+          return false;
+
+        // we hide unused income and expense accounts if the specific flag is set
+        if ((account.accountType() == MyMoneyAccount::Income || account.accountType() == MyMoneyAccount::Expense) && hideUnusedIncomeExpenseAccounts()) {
+          QVariant totalValue = sourceModel()->data(source, AccountsModel::AccountTotalValueRole);
+          if (totalValue.isValid() && totalValue.value<MyMoneyMoney>().isZero()) {
+            emit unusedIncomeExpenseAccountHidden();
+            return false;
+          }
         }
+
+        if (d->m_typeList.contains(account.accountType()))
+          return true;
       }
 
-      if (d->m_typeList.contains(account.accountType()))
-        return true;
+      if (data.canConvert<MyMoneyInstitution>()) {
+        return !hideInstitutions();
+      }
     }
 
     int rowCount = sourceModel()->rowCount(source);
@@ -765,7 +880,7 @@ void AccountsFilterProxyModel::setHideClosedAccounts(bool hideClosedAccounts)
 {
   if (d->m_hideClosedAccounts != hideClosedAccounts) {
     d->m_hideClosedAccounts = hideClosedAccounts;
-    invalidateFilter();
+    invalidate();
   }
 }
 
@@ -785,7 +900,7 @@ void AccountsFilterProxyModel::setHideEquityAccounts(bool hideEquityAccounts)
 {
   if (d->m_hideEquityAccounts != hideEquityAccounts) {
     d->m_hideEquityAccounts = hideEquityAccounts;
-    invalidateFilter();
+    invalidate();
   }
 }
 
@@ -805,7 +920,7 @@ void AccountsFilterProxyModel::setHideUnusedIncomeExpenseAccounts(bool hideUnuse
 {
   if (d->m_hideUnusedIncomeExpenseAccounts != hideUnusedIncomeExpenseAccounts) {
     d->m_hideUnusedIncomeExpenseAccounts = hideUnusedIncomeExpenseAccounts;
-    invalidateFilter();
+    invalidate();
   }
 }
 
@@ -817,4 +932,24 @@ bool AccountsFilterProxyModel::hideUnusedIncomeExpenseAccounts(void) const
   return d->m_hideUnusedIncomeExpenseAccounts;
 }
 
+/**
+  * Set if equity and investment accounts should be hidden or not.
+  * @param hideInstitutions
+  */
+void AccountsFilterProxyModel::setHideInstitutions(bool hideInstitutions)
+{
+  if (d->m_hideInstitutions != hideInstitutions) {
+    d->m_hideInstitutions = hideInstitutions;
+    invalidate();
+  }
+}
+
+/**
+  * Check if equity and investment accounts are hidden or not.
+  */
+bool AccountsFilterProxyModel::hideInstitutions(void) const
+{
+  return d->m_hideInstitutions;
+}
+
 #include "accountsmodel.moc"
