@@ -948,7 +948,7 @@ void MyMoneyFile::accountList(QList<MyMoneyAccount>& list, const QStringList& id
       if (!isStandardAccount((*it).id())) {
         if (idlist.indexOf((*it).id()) != -1) {
           list.append(*it);
-          if (recursive == true) {
+          if (recursive == true && !(*it).accountList().isEmpty()) {
             accountList(list, (*it).accountList(), true);
           }
         }
@@ -1376,24 +1376,24 @@ const QStringList MyMoneyFile::consistencyCheck(void)
     }
 
     switch ((*it_a).accountGroup()) {
-    case MyMoneyAccount::Asset:
-      toplevel = asset();
-      break;
-    case MyMoneyAccount::Liability:
-      toplevel = liability();
-      break;
-    case MyMoneyAccount::Expense:
-      toplevel = expense();
-      break;
-    case MyMoneyAccount::Income:
-      toplevel = income();
-      break;
-    case MyMoneyAccount::Equity:
-      toplevel = equity();
-      break;
-    default:
-      qWarning("%s:%d This should never happen!", __FILE__ , __LINE__);
-      break;
+      case MyMoneyAccount::Asset:
+        toplevel = asset();
+        break;
+      case MyMoneyAccount::Liability:
+        toplevel = liability();
+        break;
+      case MyMoneyAccount::Expense:
+        toplevel = expense();
+        break;
+      case MyMoneyAccount::Income:
+        toplevel = income();
+        break;
+      case MyMoneyAccount::Equity:
+        toplevel = equity();
+        break;
+      default:
+        qWarning("%s:%d This should never happen!", __FILE__ , __LINE__);
+        break;
     }
 
     // check for loops in the hierarchy
@@ -1513,6 +1513,18 @@ const QStringList MyMoneyFile::consistencyCheck(void)
         interestAccounts[loan->interestAccountId()] = true;
     }
 
+    // check for clear text online password in the online settings
+    if (!(*it_a).onlineBankingSettings().value("password").isEmpty()) {
+      if (problemAccount != (*it_a).name()) {
+        problemAccount = (*it_a).name();
+        rc << i18n("* Problem with account '%1'", problemAccount);
+      }
+      rc << i18n("  * Older versions of KMyMoney stored an OFX password for this account in cleartext.");
+      rc << i18n("    Please open it in the account editor (Account/Edit account) once and press OK.");
+      rc << i18n("    This will store the password in the KDE wallet and remove the cleartext version.");
+      ++unfixedCount;
+    }
+
     // if the account was modified, we need to update it in the engine
     if (!(m_storage->account((*it_a).id()) == (*it_a))) {
       try {
@@ -1757,14 +1769,95 @@ const QStringList MyMoneyFile::consistencyCheck(void)
     ++problemCount;
   }
 
+  //look for accounts which have currencies other than the base currency but no price on the opening date
+  //all accounts using base currency are excluded, since that's the base used for foreing currency calculation
+  //thus it is considered as always present
+
+  //get all currencies in use
+  QStringList currencyList;
+  QList<MyMoneyAccount> accountForeignCurrency;
+  QList<MyMoneyAccount> accList;
+  accountList(accList);
+  QList<MyMoneyAccount>::const_iterator account_it;
+  for (account_it = accList.constBegin(); account_it != accList.constEnd(); ++account_it) {
+    MyMoneyAccount account = *account_it;
+    if (!currencyList.contains(account.currencyId())
+        && account.currencyId() != baseCurrency().id()
+        && !account.currencyId().isEmpty()) {
+      //add the currency and the account-currency pair
+      currencyList.append(account.currencyId());
+      accountForeignCurrency.append(account);
+    }
+  }
+
+  MyMoneyPriceList pricesList = priceList();
+  QMap<MyMoneySecurityPair, QDate> securityPriceDate;
+
+  //get the first date of the price for each security
+  MyMoneyPriceList::const_iterator prices_it;
+  for (prices_it = pricesList.constBegin(); prices_it != pricesList.constEnd(); ++prices_it) {
+    MyMoneyPrice firstPrice = (*((*prices_it).constBegin()));
+
+    //only check the price if the currency is in use
+    if (currencyList.contains(firstPrice.from()) || currencyList.contains(firstPrice.to())) {
+      //check the security in the from field
+      //if it is there, check if it is older
+      QPair<QString, QString> pricePair = qMakePair(firstPrice.from(), firstPrice.to());
+      securityPriceDate[pricePair] = firstPrice.date();
+    }
+  }
+
+  //compare the dates with the opening dates of the accounts using each currency
+  QList<MyMoneyAccount>::const_iterator accForeignList_it;
+  bool firstInvProblem = true;
+  for (accForeignList_it = accountForeignCurrency.constBegin(); accForeignList_it != accountForeignCurrency.constEnd(); ++accForeignList_it) {
+    //setup the price pair correctly
+    QPair<QString, QString> pricePair;
+    //setup the reverse, which can also be used for rate conversion
+    QPair<QString, QString> reversePricePair;
+    if ((*accForeignList_it).isInvest()) {
+      //if it is a stock, we have to search for a price from its stock to the currency of the account
+      QString securityId = (*accForeignList_it).currencyId();
+      QString tradingCurrencyId = security(securityId).tradingCurrency();
+      pricePair = qMakePair(securityId, tradingCurrencyId);
+      reversePricePair = qMakePair(tradingCurrencyId, securityId);
+    } else {
+      //if it is a regular account we search for a price from the currency of the account to the base currency
+      QString currency = (*accForeignList_it).currencyId();
+      QString baseCurrencyId = baseCurrency().id();
+      pricePair = qMakePair(currency, baseCurrencyId);
+      reversePricePair = qMakePair(baseCurrencyId, currency);
+    }
+
+    //compare the first price with the opening date of the account
+    if ((!securityPriceDate.contains(pricePair) || securityPriceDate.value(pricePair) > (*accForeignList_it).openingDate())
+        && (!securityPriceDate.contains(reversePricePair) || securityPriceDate.value(reversePricePair) > (*accForeignList_it).openingDate())) {
+      if (firstInvProblem) {
+        firstInvProblem = false;
+        rc << i18n("* Potential problem with investments/currencies");
+      }
+      QDate openingDate = (*accForeignList_it).openingDate();
+      MyMoneySecurity secError = security((*accForeignList_it).currencyId());
+      if (!(*accForeignList_it).isInvest()) {
+        rc << i18n("  * The account '%1' in currency '%2' has no price set for the opening date '%3'.", (*accForeignList_it).name(), secError.name(), openingDate.toString(Qt::ISODate));
+        rc << i18n("    Please enter a price for the currency on or before the opening date.");
+      } else {
+        rc << i18n("  * The investment '%1' has no price set for the opening date '%2'.", (*accForeignList_it).name(), openingDate.toString(Qt::ISODate));
+        rc << i18n("    Please enter a price for the investment on or before the opening date.");
+      }
+      ++unfixedCount;
+    }
+  }
+
   // add more checks here
 
-  if (problemCount == 0) {
+  if (problemCount == 0 && unfixedCount == 0) {
     rc << i18n("Finished: data is consistent.");
   } else {
     const QString problemsCorrected = i18np("%1 problem corrected.", "%1 problems corrected.", problemCount);
     const QString problemsRemaining = i18np("%1 problem still present.", "%1 problems still present.", unfixedCount);
 
+    rc << QString();
     rc << i18nc("%1 is a string, e.g. 7 problems corrected; %2 is a string, e.g. 3 problems still present", "Finished: %1 %2", problemsCorrected, problemsRemaining);
   }
   return rc;
@@ -1931,8 +2024,11 @@ const MyMoneySecurity& MyMoneyFile::currency(const QString& id) const
     return baseCurrency();
 
   const MyMoneySecurity& curr = d->m_cache.security(id);
-  if (curr.id().isEmpty())
-    throw new MYMONEYEXCEPTION("Currency not found.");
+  if (curr.id().isEmpty()) {
+    QString msg;
+    msg = QString("Currency '%1' not found.").arg(id);
+    throw new MYMONEYEXCEPTION(msg);
+  }
   return curr;
 }
 
