@@ -13,8 +13,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef _MYMONEYMONEY_H
-#define _MYMONEYMONEY_H
+#ifndef MYMONEYMONEY_H
+#define MYMONEYMONEY_H
 
 #include <stdlib.h>
 
@@ -22,22 +22,8 @@
 #include <config-kmymoney.h>
 #endif
 
-#ifndef HAVE_ATOLL
-#  ifdef HAVE_STRTOLL
-#    define atoll(a) strtoll(a, 0, 10)
-#  endif
-#endif
-
 #include <cmath>
 
-#ifdef _GLIBCPP_HAVE_MODFL
-#define HAVE_LONG_DOUBLE  1
-#endif
-
-#ifndef HAVE_LONG_DOUBLE
-#define HAVE_LONG_DOUBLE  0
-#endif
-
 // So we can save this object
 #include <QChar>
 #include <QString>
@@ -72,6 +58,8 @@ class MyMoneySecurity;
   */
 class KMM_MYMONEY_EXPORT MyMoneyMoney
 {
+  KMM_MYMONEY_UNIT_TESTABLE
+
 public:
   enum fileVersionE {
     FILE_4_BYTE_VALUE = 0,
@@ -105,7 +93,7 @@ public:
   explicit MyMoneyMoney(const QString& pszAmount);
   explicit MyMoneyMoney(const signed64 Amount, const signed64 denom = 100);
   explicit MyMoneyMoney(const double dAmount, const signed64 denom = 100);
-#if HAVE_LONG_DOUBLE
+#ifdef SIZEOF_LONG_DOUBLE
   explicit MyMoneyMoney(const long double dAmount, const signed64 denom = 100);
 #endif
 
@@ -312,7 +300,7 @@ inline MyMoneyMoney::MyMoneyMoney(const double dAmount, const signed64 denom)
   m_num = (signed64)(dAmount * (double)m_denom + adj);
 }
 
-#if HAVE_LONG_DOUBLE
+#ifdef SIZEOF_LONG_DOUBLE
 ////////////////////////////////////////////////////////////////////////////////
 //      Name: MyMoneyMoney
 //   Purpose: Constructor - constructs object from an amount in a long double value
@@ -653,6 +641,9 @@ inline MyMoneyMoney& MyMoneyMoney::operator/=(const MyMoneyMoney & AmountInPence
   return *this;
 }
 
+/**
+  * Make it possible to hold @ref MyMoneyMoney objects inside @ref QVariant objects.
+  */
 Q_DECLARE_METATYPE(MyMoneyMoney)
 
 #endif
