@@ -476,6 +476,12 @@ public:
     */
   virtual bool hasReferenceTo(const QString& id) const;
 
+  /**
+    * This method allows to modify the default lineWidth for graphs.
+    * The default is 2.
+    */
+  static void setLineWidth(int width);
+
 private:
   /**
     * The user-assigned name of the report
@@ -642,6 +648,17 @@ private:
    */
   int m_currentDateColumn;
 
+  /**
+    * This member keeps the current setting for line graphs lineWidth.
+    * @sa setLineWidth()
+    */
+  static int m_lineWidth;
+
 };
 
+/**
+  * Make it possible to hold @ref MyMoneyReport objects inside @ref QVariant objects.
+  */
+Q_DECLARE_METATYPE(MyMoneyReport)
+
 #endif // MYMONEYREPORT_H
