@@ -88,8 +88,8 @@ MyMoneySchedule::MyMoneySchedule(const QDomElement& node) :
 
   m_type = static_cast<MyMoneySchedule::typeE>(node.attribute("type").toInt());
   m_paymentType = static_cast<MyMoneySchedule::paymentTypeE>(node.attribute("paymentType").toInt());
-  m_occurrence = static_cast<MyMoneySchedule::occurrenceE>(node.attribute("occurence").toInt());
-  m_occurrenceMultiplier = node.attribute("occurenceMultiplier", "1").toInt();
+  m_occurrence = static_cast<MyMoneySchedule::occurrenceE>(node.attribute("occurence").toInt()); // krazy:exclude=spelling
+  m_occurrenceMultiplier = node.attribute("occurenceMultiplier", "1").toInt(); // krazy:exclude=spelling
   // Convert to compound occurrence
   simpleToCompoundOccurrence(m_occurrenceMultiplier, m_occurrence);
   m_autoEnter = static_cast<bool>(node.attribute("autoEnter").toInt());
@@ -370,104 +370,123 @@ void MyMoneySchedule::validate(bool id_check) const
 
   // Check the payment types
   switch (m_type) {
-  case TYPE_BILL:
-    if (m_paymentType == STYPE_DIRECTDEPOSIT || m_paymentType == STYPE_MANUALDEPOSIT)
-      throw new MYMONEYEXCEPTION("Invalid payment type for bills");
-    break;
+    case TYPE_BILL:
+      if (m_paymentType == STYPE_DIRECTDEPOSIT || m_paymentType == STYPE_MANUALDEPOSIT)
+        throw new MYMONEYEXCEPTION("Invalid payment type for bills");
+      break;
 
-  case TYPE_DEPOSIT:
-    if (m_paymentType == STYPE_DIRECTDEBIT || m_paymentType == STYPE_WRITECHEQUE)
-      throw new MYMONEYEXCEPTION("Invalid payment type for deposits");
-    break;
+    case TYPE_DEPOSIT:
+      if (m_paymentType == STYPE_DIRECTDEBIT || m_paymentType == STYPE_WRITECHEQUE)
+        throw new MYMONEYEXCEPTION("Invalid payment type for deposits");
+      break;
 
-  case TYPE_ANY:
-    throw new MYMONEYEXCEPTION("Invalid type ANY");
-    break;
+    case TYPE_ANY:
+      throw new MYMONEYEXCEPTION("Invalid type ANY");
+      break;
 
-  case TYPE_TRANSFER:
+    case TYPE_TRANSFER:
 //        if (m_paymentType == STYPE_DIRECTDEPOSIT || m_paymentType == STYPE_MANUALDEPOSIT)
 //          return false;
-    break;
+      break;
 
-  case TYPE_LOANPAYMENT:
-    break;
+    case TYPE_LOANPAYMENT:
+      break;
   }
 }
 
 QDate MyMoneySchedule::adjustedNextPayment(const QDate& refDate) const
 {
-  QDate date(nextPayment(refDate));
-  return date.isValid() ? adjustedDate(date, weekendOption()) : date;
+  return nextPaymentDate(true, refDate);
 }
 
 QDate MyMoneySchedule::nextPayment(const QDate& refDate) const
 {
+  return nextPaymentDate(false, refDate);
+}
+
+QDate MyMoneySchedule::nextPaymentDate(const bool& adjust, const QDate& refDate) const
+{
+  weekendOptionE option(adjust ? weekendOption() :
+                        MyMoneySchedule::MoveNothing);
+
   // if the enddate is valid and it is before the reference date,
   // then there will be no more payments.
   if (m_endDate.isValid() && m_endDate < refDate) {
     return QDate();
   }
 
-  QDate paymentDate(nextDueDate());
+  QDate dueDate(nextDueDate());
+  QDate paymentDate(adjustedDate(dueDate, option));
 
-  if (refDate >= paymentDate) {
+  if (paymentDate.isValid() &&
+      (paymentDate <= refDate || m_recordedPayments.contains(dueDate))) {
     switch (m_occurrence) {
-    case OCCUR_ONCE:
-      // if the lastPayment is already set, then there will be no more payments
-      // otherwise, the start date is the payment date
-      if (m_lastPayment.isValid())
-        return QDate();
-      // if the only payment should have been prior to the reference date,
-      // then don't show it
-      if (nextDueDate() < refDate)
-        return QDate();
-      break;
+      case OCCUR_ONCE:
+        // If the lastPayment is already set or the payment should have been
+        // prior to the reference date then invalidate the payment date.
+        if (m_lastPayment.isValid() || paymentDate <= refDate)
+          paymentDate = QDate();
+        break;
 
-    case OCCUR_DAILY:
-      paymentDate = refDate.addDays(m_occurrenceMultiplier);
-      break;
+      case OCCUR_DAILY: {
+          int step = m_occurrenceMultiplier;
+          do {
+            dueDate = dueDate.addDays(step);
+            paymentDate = adjustedDate(dueDate, option);
+          } while (paymentDate.isValid() &&
+                   (paymentDate <= refDate ||
+                    m_recordedPayments.contains(dueDate)));
+        }
+        break;
 
-    case OCCUR_WEEKLY: {
-      int step = 7 * m_occurrenceMultiplier;
-      do {
-        paymentDate = paymentDate.addDays(step);
-      } while (paymentDate <= refDate);
-    }
-    break;
+      case OCCUR_WEEKLY: {
+          int step = 7 * m_occurrenceMultiplier;
+          do {
+            dueDate = dueDate.addDays(step);
+            paymentDate = adjustedDate(dueDate, option);
+          } while (paymentDate.isValid() &&
+                   (paymentDate <= refDate ||
+                    m_recordedPayments.contains(dueDate)));
+        }
+        break;
 
-    case OCCUR_EVERYHALFMONTH:
-      do {
-        paymentDate = addHalfMonths(paymentDate, m_occurrenceMultiplier);
-      } while (paymentDate <= refDate);
-      break;
+      case OCCUR_EVERYHALFMONTH:
+        do {
+          dueDate = addHalfMonths(dueDate, m_occurrenceMultiplier);
+          paymentDate = adjustedDate(dueDate, option);
+        } while (paymentDate.isValid() &&
+                 (paymentDate <= refDate ||
+                  m_recordedPayments.contains(dueDate)));
+        break;
 
-    case OCCUR_MONTHLY:
-      do {
-        paymentDate = paymentDate.addMonths(m_occurrenceMultiplier);
-        fixDate(paymentDate);
-      } while (paymentDate <= refDate);
-      break;
+      case OCCUR_MONTHLY:
+        do {
+          dueDate = dueDate.addMonths(m_occurrenceMultiplier);
+          fixDate(dueDate);
+          paymentDate = adjustedDate(dueDate, option);
+        } while (paymentDate.isValid() &&
+                 (paymentDate <= refDate ||
+                  m_recordedPayments.contains(dueDate)));
+        break;
 
-    case OCCUR_YEARLY:
-      do {
-        paymentDate = paymentDate.addYears(m_occurrenceMultiplier);
-        fixDate(paymentDate);
-      } while (paymentDate <= refDate);
-      break;
+      case OCCUR_YEARLY:
+        do {
+          dueDate = dueDate.addYears(m_occurrenceMultiplier);
+          fixDate(dueDate);
+          paymentDate = adjustedDate(dueDate, option);
+        } while (paymentDate.isValid() &&
+                 (paymentDate <= refDate ||
+                  m_recordedPayments.contains(dueDate)));
+        break;
 
-    case OCCUR_ANY:
-    default:
-      paymentDate = QDate();
-      break;
+      case OCCUR_ANY:
+      default:
+        paymentDate = QDate();
+        break;
     }
   }
-  if (paymentDate.isValid()) {
-    if (m_endDate.isValid() && paymentDate > m_endDate)
-      paymentDate = QDate();
-  }
-
-  if (paymentDate.isValid() && m_recordedPayments.contains(paymentDate))
-    paymentDate = nextPayment(paymentDate);
+  if (paymentDate.isValid() && m_endDate.isValid() && paymentDate > m_endDate)
+    paymentDate = QDate();
 
   return paymentDate;
 }
@@ -492,63 +511,63 @@ QList<QDate> MyMoneySchedule::paymentDates(const QDate& _startDate, const QDate&
   QDate date(adjustedDate(paymentDate, option));
 
   switch (m_occurrence) {
-  case OCCUR_ONCE:
-    if (start_date >= _startDate && start_date <= endDate)
-      theDates.append(start_date);
-    break;
+    case OCCUR_ONCE:
+      if (start_date >= _startDate && start_date <= endDate)
+        theDates.append(start_date);
+      break;
 
-  case OCCUR_DAILY:
-    while (date.isValid() && (date <= endDate)) {
-      if (date >= _startDate)
-        theDates.append(date);
-      paymentDate = paymentDate.addDays(m_occurrenceMultiplier);
-      date = adjustedDate(paymentDate, option);
-    }
-    break;
+    case OCCUR_DAILY:
+      while (date.isValid() && (date <= endDate)) {
+        if (date >= _startDate)
+          theDates.append(date);
+        paymentDate = paymentDate.addDays(m_occurrenceMultiplier);
+        date = adjustedDate(paymentDate, option);
+      }
+      break;
 
-  case OCCUR_WEEKLY: {
-    int step = 7 * m_occurrenceMultiplier;
-    while (date.isValid() && (date <= endDate)) {
-      if (date >= _startDate)
-        theDates.append(date);
-      paymentDate = paymentDate.addDays(step);
-      date = adjustedDate(paymentDate, option);
-    }
-  }
-  break;
+    case OCCUR_WEEKLY: {
+        int step = 7 * m_occurrenceMultiplier;
+        while (date.isValid() && (date <= endDate)) {
+          if (date >= _startDate)
+            theDates.append(date);
+          paymentDate = paymentDate.addDays(step);
+          date = adjustedDate(paymentDate, option);
+        }
+      }
+      break;
 
-  case OCCUR_EVERYHALFMONTH:
-    while (date.isValid() && (date <= endDate)) {
-      if (date >= _startDate)
-        theDates.append(date);
-      paymentDate = addHalfMonths(paymentDate, m_occurrenceMultiplier);
-      date = adjustedDate(paymentDate, option);
-    }
-    break;
+    case OCCUR_EVERYHALFMONTH:
+      while (date.isValid() && (date <= endDate)) {
+        if (date >= _startDate)
+          theDates.append(date);
+        paymentDate = addHalfMonths(paymentDate, m_occurrenceMultiplier);
+        date = adjustedDate(paymentDate, option);
+      }
+      break;
 
-  case OCCUR_MONTHLY:
-    while (date.isValid() && (date <= endDate)) {
-      if (date >= _startDate)
-        theDates.append(date);
-      paymentDate = paymentDate.addMonths(m_occurrenceMultiplier);
-      fixDate(paymentDate);
-      date = adjustedDate(paymentDate, option);
-    }
-    break;
+    case OCCUR_MONTHLY:
+      while (date.isValid() && (date <= endDate)) {
+        if (date >= _startDate)
+          theDates.append(date);
+        paymentDate = paymentDate.addMonths(m_occurrenceMultiplier);
+        fixDate(paymentDate);
+        date = adjustedDate(paymentDate, option);
+      }
+      break;
 
-  case OCCUR_YEARLY:
-    while (date.isValid() && (date <= endDate)) {
-      if (date >= _startDate)
-        theDates.append(date);
-      paymentDate = paymentDate.addYears(m_occurrenceMultiplier);
-      fixDate(paymentDate);
-      date = adjustedDate(paymentDate, option);
-    }
-    break;
+    case OCCUR_YEARLY:
+      while (date.isValid() && (date <= endDate)) {
+        if (date >= _startDate)
+          theDates.append(date);
+        paymentDate = paymentDate.addYears(m_occurrenceMultiplier);
+        fixDate(paymentDate);
+        date = adjustedDate(paymentDate, option);
+      }
+      break;
 
-  case OCCUR_ANY:
-  default:
-    break;
+    case OCCUR_ANY:
+    default:
+      break;
   }
 
   return theDates;
@@ -578,12 +597,17 @@ bool MyMoneySchedule::operator ==(const MyMoneySchedule& right) const
 }
 
 int MyMoneySchedule::transactionsRemaining(void) const
+{
+  return transactionsRemainingUntil(m_endDate);
+}
+
+int MyMoneySchedule::transactionsRemainingUntil(const QDate& endDate) const
 {
   int counter = 0;
 
-  if (m_endDate.isValid()) {
-    QList<QDate> dates = paymentDates(m_lastPayment, m_endDate);
-    // Do not include the last payment so -1
+  QDate startDate = m_lastPayment.isValid() ? m_lastPayment : m_startDate;
+  if (startDate.isValid() && endDate.isValid()) {
+    QList<QDate> dates = paymentDates(startDate, endDate);
     counter = dates.count();
   }
   return counter;
@@ -624,38 +648,38 @@ QDate MyMoneySchedule::dateAfter(int transactions) const
     return paymentDate;
 
   switch (m_occurrence) {
-  case OCCUR_ONCE:
-    break;
+    case OCCUR_ONCE:
+      break;
 
-  case OCCUR_DAILY:
-    while (counter++ < transactions)
-      paymentDate = paymentDate.addDays(m_occurrenceMultiplier);
-    break;
+    case OCCUR_DAILY:
+      while (counter++ < transactions)
+        paymentDate = paymentDate.addDays(m_occurrenceMultiplier);
+      break;
 
-  case OCCUR_WEEKLY: {
-    int step = 7 * m_occurrenceMultiplier;
-    while (counter++ < transactions)
-      paymentDate = paymentDate.addDays(step);
-  }
-  break;
+    case OCCUR_WEEKLY: {
+        int step = 7 * m_occurrenceMultiplier;
+        while (counter++ < transactions)
+          paymentDate = paymentDate.addDays(step);
+      }
+      break;
 
-  case OCCUR_EVERYHALFMONTH:
-    paymentDate = addHalfMonths(paymentDate, m_occurrenceMultiplier * (transactions - 1));
-    break;
+    case OCCUR_EVERYHALFMONTH:
+      paymentDate = addHalfMonths(paymentDate, m_occurrenceMultiplier * (transactions - 1));
+      break;
 
-  case OCCUR_MONTHLY:
-    while (counter++ < transactions)
-      paymentDate = paymentDate.addMonths(m_occurrenceMultiplier);
-    break;
+    case OCCUR_MONTHLY:
+      while (counter++ < transactions)
+        paymentDate = paymentDate.addMonths(m_occurrenceMultiplier);
+      break;
 
-  case OCCUR_YEARLY:
-    while (counter++ < transactions)
-      paymentDate = paymentDate.addYears(m_occurrenceMultiplier);
-    break;
+    case OCCUR_YEARLY:
+      while (counter++ < transactions)
+        paymentDate = paymentDate.addYears(m_occurrenceMultiplier);
+      break;
 
-  case OCCUR_ANY:
-  default:
-    break;
+    case OCCUR_ANY:
+    default:
+      break;
   }
 
   return paymentDate;
@@ -712,14 +736,14 @@ void MyMoneySchedule::setWeekendOption(const weekendOptionE option)
 {
   // make sure only valid values are used. Invalid defaults to MoveNothing.
   switch (option) {
-  case MoveBefore:
-  case MoveAfter:
-    m_weekendOption = option;
-    break;
+    case MoveBefore:
+    case MoveAfter:
+      m_weekendOption = option;
+      break;
 
-  default:
-    m_weekendOption = MoveNothing;
-    break;
+    default:
+      m_weekendOption = MoveNothing;
+      break;
   }
 }
 
@@ -741,7 +765,7 @@ void MyMoneySchedule::writeXML(QDomDocument& document, QDomElement& parent) cons
 
   el.setAttribute("name", m_name);
   el.setAttribute("type", m_type);
-  el.setAttribute("occurence", m_occurrence);
+  el.setAttribute("occurence", m_occurrence); // krazy:exclude=spelling
   el.setAttribute("occurenceMultiplier", m_occurrenceMultiplier);
   el.setAttribute("paymentType", m_paymentType);
   el.setAttribute("startDate", dateToString(m_startDate));
@@ -780,110 +804,148 @@ QString MyMoneySchedule::occurrenceToString() const
 
 QString MyMoneySchedule::occurrenceToString(occurrenceE occurrence)
 {
-  QString occurrenceString = I18N_NOOP("Any");
+  QString occurrenceString = I18N_NOOP2("Frequency of schedule", "Any");
 
   if (occurrence == MyMoneySchedule::OCCUR_ONCE)
-    occurrenceString = I18N_NOOP("Once");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Once");
   else if (occurrence == MyMoneySchedule::OCCUR_DAILY)
-    occurrenceString = I18N_NOOP("Daily");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Daily");
   else if (occurrence == MyMoneySchedule::OCCUR_WEEKLY)
-    occurrenceString = I18N_NOOP("Weekly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Weekly");
   else if (occurrence == MyMoneySchedule::OCCUR_FORTNIGHTLY)
-    occurrenceString = I18N_NOOP("Fortnightly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Fortnightly");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYOTHERWEEK)
-    occurrenceString = I18N_NOOP("Every other week");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every other week");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYHALFMONTH)
-    occurrenceString = I18N_NOOP("Every half month");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every half month");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYTHREEWEEKS)
-    occurrenceString = I18N_NOOP("Every three weeks");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every three weeks");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYFOURWEEKS)
-    occurrenceString = I18N_NOOP("Every four weeks");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every four weeks");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS)
-    occurrenceString = I18N_NOOP("Every thirty days");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every thirty days");
   else if (occurrence == MyMoneySchedule::OCCUR_MONTHLY)
-    occurrenceString = I18N_NOOP("Monthly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Monthly");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS)
-    occurrenceString = I18N_NOOP("Every eight weeks");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every eight weeks");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYOTHERMONTH)
-    occurrenceString = I18N_NOOP("Every two months");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every two months");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYTHREEMONTHS)
-    occurrenceString = I18N_NOOP("Every three months");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every three months");
   else if (occurrence == MyMoneySchedule::OCCUR_QUARTERLY)
-    occurrenceString = I18N_NOOP("Quarterly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Quarterly");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYFOURMONTHS)
-    occurrenceString = I18N_NOOP("Every four months");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every four months");
   else if (occurrence == MyMoneySchedule::OCCUR_TWICEYEARLY)
-    occurrenceString = I18N_NOOP("Twice yearly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Twice yearly");
   else if (occurrence == MyMoneySchedule::OCCUR_YEARLY)
-    occurrenceString = I18N_NOOP("Yearly");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Yearly");
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYOTHERYEAR)
-    occurrenceString = I18N_NOOP("Every other year");
+    occurrenceString = I18N_NOOP2("Frequency of schedule", "Every other year");
   return occurrenceString;
 }
 
 QString MyMoneySchedule::occurrenceToString(int mult, occurrenceE type)
 {
-  QString occurrenceString = I18N_NOOP("Any");
+  QString occurrenceString = I18N_NOOP2("Frequency of schedule", "Any");
 
   if (type == MyMoneySchedule::OCCUR_ONCE)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Once"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("%1 times").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Once");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("%1 times").arg(mult));
     }
   else if (type == MyMoneySchedule::OCCUR_DAILY)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Daily"); break;
-    case 30: occurrenceString = I18N_NOOP("Every thirty days"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("Every %1 days").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Daily");
+        break;
+      case 30:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every thirty days");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("Every %1 days").arg(mult));
     }
   else if (type == MyMoneySchedule::OCCUR_WEEKLY)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Weekly"); break;
-    case 2: occurrenceString = I18N_NOOP("Every other week"); break;
-    case 3: occurrenceString = I18N_NOOP("Every three weeks"); break;
-    case 4: occurrenceString = I18N_NOOP("Every four weeks"); break;
-    case 8: occurrenceString = I18N_NOOP("Every eight weeks"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("Every %1 weeks").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Weekly");
+        break;
+      case 2:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every other week");
+        break;
+      case 3:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every three weeks");
+        break;
+      case 4:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every four weeks");
+        break;
+      case 8:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every eight weeks");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("Every %1 weeks").arg(mult));
     }
   else if (type == MyMoneySchedule::OCCUR_EVERYHALFMONTH)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Every half month"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("Every %1 half months").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every half month");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("Every %1 half months").arg(mult));
     }
   else if (type == MyMoneySchedule::OCCUR_MONTHLY)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Monthly"); break;
-    case 2: occurrenceString = I18N_NOOP("Every two months"); break;
-    case 3: occurrenceString = I18N_NOOP("Every three months"); break;
-    case 4: occurrenceString = I18N_NOOP("Every four months"); break;
-    case 6: occurrenceString = I18N_NOOP("Twice yearly"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("Every %1 months").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Monthly");
+        break;
+      case 2:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every two months");
+        break;
+      case 3:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every three months");
+        break;
+      case 4:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every four months");
+        break;
+      case 6:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Twice yearly");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("Every %1 months").arg(mult));
     }
   else if (type == MyMoneySchedule::OCCUR_YEARLY)
     switch (mult) {
-    case 1: occurrenceString = I18N_NOOP("Yearly"); break;
-    case 2: occurrenceString = I18N_NOOP("Every other year"); break;
-    default: occurrenceString = I18N_NOOP(static_cast<QString>("Every %1 years").arg(mult));
+      case 1:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Yearly");
+        break;
+      case 2:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", "Every other year");
+        break;
+      default:
+        occurrenceString = I18N_NOOP2("Frequency of schedule", QString("Every %1 years").arg(mult));
     }
   return occurrenceString;
 }
 
 QString MyMoneySchedule::occurrencePeriodToString(MyMoneySchedule::occurrenceE type)
 {
-  QString occurrenceString = I18N_NOOP("Any");
+  QString occurrenceString = I18N_NOOP2("Schedule occurrence period", "Any");
 
   if (type == MyMoneySchedule::OCCUR_ONCE)
-    occurrenceString = I18N_NOOP("Once");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Once");
   else if (type == MyMoneySchedule::OCCUR_DAILY)
-    occurrenceString = I18N_NOOP("Day");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Day");
   else if (type == MyMoneySchedule::OCCUR_WEEKLY)
-    occurrenceString = I18N_NOOP("Week");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Week");
   else if (type == MyMoneySchedule::OCCUR_EVERYHALFMONTH)
-    occurrenceString = I18N_NOOP("Half-month");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Half-month");
   else if (type == MyMoneySchedule::OCCUR_MONTHLY)
-    occurrenceString = I18N_NOOP("Month");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Month");
   else if (type == MyMoneySchedule::OCCUR_YEARLY)
-    occurrenceString = I18N_NOOP("Year");
+    occurrenceString = I18N_NOOP2("Schedule occurrence period", "Year");
   return occurrenceString;
 }
 
@@ -892,21 +954,21 @@ QString MyMoneySchedule::scheduleTypeToString(MyMoneySchedule::typeE type)
   QString text;
 
   switch (type) {
-  case MyMoneySchedule::TYPE_BILL:
-    text = I18N_NOOP("Bill");
-    break;
-  case MyMoneySchedule::TYPE_DEPOSIT:
-    text = I18N_NOOP("Deposit");
-    break;
-  case MyMoneySchedule::TYPE_TRANSFER:
-    text = I18N_NOOP("Transfer");
-    break;
-  case MyMoneySchedule::TYPE_LOANPAYMENT:
-    text = I18N_NOOP("Loan payment");
-    break;
-  case MyMoneySchedule::TYPE_ANY:
-  default:
-    text = I18N_NOOP("Unknown");
+    case MyMoneySchedule::TYPE_BILL:
+      text = I18N_NOOP2("Scheduled transaction type", "Bill");
+      break;
+    case MyMoneySchedule::TYPE_DEPOSIT:
+      text = I18N_NOOP2("Scheduled transaction type", "Deposit");
+      break;
+    case MyMoneySchedule::TYPE_TRANSFER:
+      text = I18N_NOOP2("Scheduled transaction type", "Transfer");
+      break;
+    case MyMoneySchedule::TYPE_LOANPAYMENT:
+      text = I18N_NOOP2("Scheduled transaction type", "Loan payment");
+      break;
+    case MyMoneySchedule::TYPE_ANY:
+    default:
+      text = I18N_NOOP2("Scheduled transaction type", "Unknown");
   }
   return text;
 }
@@ -917,30 +979,30 @@ QString MyMoneySchedule::paymentMethodToString(MyMoneySchedule::paymentTypeE pay
   QString text;
 
   switch (paymentType) {
-  case MyMoneySchedule::STYPE_DIRECTDEBIT:
-    text = I18N_NOOP("Direct debit");
-    break;
-  case MyMoneySchedule::STYPE_DIRECTDEPOSIT:
-    text = I18N_NOOP("Direct deposit");
-    break;
-  case MyMoneySchedule::STYPE_MANUALDEPOSIT:
-    text = I18N_NOOP("Manual deposit");
-    break;
-  case MyMoneySchedule::STYPE_OTHER:
-    text = I18N_NOOP("Other");
-    break;
-  case MyMoneySchedule::STYPE_WRITECHEQUE:
-    text = I18N_NOOP("Write check");
-    break;
-  case MyMoneySchedule::STYPE_STANDINGORDER:
-    text = I18N_NOOP("Standing order");
-    break;
-  case MyMoneySchedule::STYPE_BANKTRANSFER:
-    text = I18N_NOOP("Bank transfer");
-    break;
-  case MyMoneySchedule::STYPE_ANY:
-    text = I18N_NOOP("Any (Error)");
-    break;
+    case MyMoneySchedule::STYPE_DIRECTDEBIT:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Direct debit");
+      break;
+    case MyMoneySchedule::STYPE_DIRECTDEPOSIT:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Direct deposit");
+      break;
+    case MyMoneySchedule::STYPE_MANUALDEPOSIT:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Manual deposit");
+      break;
+    case MyMoneySchedule::STYPE_OTHER:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Other");
+      break;
+    case MyMoneySchedule::STYPE_WRITECHEQUE:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Write check");
+      break;
+    case MyMoneySchedule::STYPE_STANDINGORDER:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Standing order");
+      break;
+    case MyMoneySchedule::STYPE_BANKTRANSFER:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Bank transfer");
+      break;
+    case MyMoneySchedule::STYPE_ANY:
+      text = I18N_NOOP2("Scheduled Transaction payment type", "Any (Error)");
+      break;
   }
   return text;
 }
@@ -950,15 +1012,15 @@ QString MyMoneySchedule::weekendOptionToString(MyMoneySchedule::weekendOptionE w
   QString text;
 
   switch (weekendOption) {
-  case MyMoneySchedule::MoveBefore:
-    text = I18N_NOOP("Change the date to the previous processing day");
-    break;
-  case MyMoneySchedule::MoveAfter:
-    text = I18N_NOOP("Change the date to the next processing day");
-    break;
-  case MyMoneySchedule::MoveNothing:
-    text = I18N_NOOP("Do Nothing");
-    break;
+    case MyMoneySchedule::MoveBefore:
+      text = I18N_NOOP("Change the date to the previous processing day");
+      break;
+    case MyMoneySchedule::MoveAfter:
+      text = I18N_NOOP("Change the date to the next processing day");
+      break;
+    case MyMoneySchedule::MoveNothing:
+      text = I18N_NOOP("Do Nothing");
+      break;
   }
   return text;
 }
@@ -998,52 +1060,52 @@ int MyMoneySchedule::eventsPerYear(MyMoneySchedule::occurrenceE occurrence)
   int rc = 0;
 
   switch (occurrence) {
-  case MyMoneySchedule::OCCUR_DAILY:
-    rc = 365;
-    break;
-  case MyMoneySchedule::OCCUR_WEEKLY:
-    rc = 52;
-    break;
-  case MyMoneySchedule::OCCUR_FORTNIGHTLY:
-    rc = 26;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYOTHERWEEK:
-    rc = 26;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
-    rc = 24;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYTHREEWEEKS:
-    rc = 17;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYFOURWEEKS:
-    rc = 13;
-    break;
-  case MyMoneySchedule::OCCUR_MONTHLY:
-  case MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS:
-    rc = 12;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS:
-    rc = 6;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYOTHERMONTH:
-    rc = 6;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYTHREEMONTHS:
-  case MyMoneySchedule::OCCUR_QUARTERLY:
-    rc = 4;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYFOURMONTHS:
-    rc = 3;
-    break;
-  case MyMoneySchedule::OCCUR_TWICEYEARLY:
-    rc = 2;
-    break;
-  case MyMoneySchedule::OCCUR_YEARLY:
-    rc = 1;
-    break;
-  default:
-    qWarning("Occurrence not supported by financial calculator");
+    case MyMoneySchedule::OCCUR_DAILY:
+      rc = 365;
+      break;
+    case MyMoneySchedule::OCCUR_WEEKLY:
+      rc = 52;
+      break;
+    case MyMoneySchedule::OCCUR_FORTNIGHTLY:
+      rc = 26;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYOTHERWEEK:
+      rc = 26;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
+      rc = 24;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYTHREEWEEKS:
+      rc = 17;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYFOURWEEKS:
+      rc = 13;
+      break;
+    case MyMoneySchedule::OCCUR_MONTHLY:
+    case MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS:
+      rc = 12;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS:
+      rc = 6;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYOTHERMONTH:
+      rc = 6;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYTHREEMONTHS:
+    case MyMoneySchedule::OCCUR_QUARTERLY:
+      rc = 4;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYFOURMONTHS:
+      rc = 3;
+      break;
+    case MyMoneySchedule::OCCUR_TWICEYEARLY:
+      rc = 2;
+      break;
+    case MyMoneySchedule::OCCUR_YEARLY:
+      rc = 1;
+      break;
+    default:
+      qWarning("Occurrence not supported by financial calculator");
   }
 
   return rc;
@@ -1054,54 +1116,54 @@ int MyMoneySchedule::daysBetweenEvents(MyMoneySchedule::occurrenceE occurrence)
   int rc = 0;
 
   switch (occurrence) {
-  case MyMoneySchedule::OCCUR_DAILY:
-    rc = 1;
-    break;
-  case MyMoneySchedule::OCCUR_WEEKLY:
-    rc = 7;
-    break;
-  case MyMoneySchedule::OCCUR_FORTNIGHTLY:
-    rc = 14;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYOTHERWEEK:
-    rc = 14;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
-    rc = 15;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYTHREEWEEKS:
-    rc = 21;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYFOURWEEKS:
-    rc = 28;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS:
-    rc = 30;
-    break;
-  case MyMoneySchedule::OCCUR_MONTHLY:
-    rc = 30;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS:
-    rc = 56;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYOTHERMONTH:
-    rc = 60;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYTHREEMONTHS:
-  case MyMoneySchedule::OCCUR_QUARTERLY:
-    rc = 90;
-    break;
-  case MyMoneySchedule::OCCUR_EVERYFOURMONTHS:
-    rc = 120;
-    break;
-  case MyMoneySchedule::OCCUR_TWICEYEARLY:
-    rc = 180;
-    break;
-  case MyMoneySchedule::OCCUR_YEARLY:
-    rc = 360;
-    break;
-  default:
-    qWarning("Occurrence not supported by financial calculator");
+    case MyMoneySchedule::OCCUR_DAILY:
+      rc = 1;
+      break;
+    case MyMoneySchedule::OCCUR_WEEKLY:
+      rc = 7;
+      break;
+    case MyMoneySchedule::OCCUR_FORTNIGHTLY:
+      rc = 14;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYOTHERWEEK:
+      rc = 14;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYHALFMONTH:
+      rc = 15;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYTHREEWEEKS:
+      rc = 21;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYFOURWEEKS:
+      rc = 28;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS:
+      rc = 30;
+      break;
+    case MyMoneySchedule::OCCUR_MONTHLY:
+      rc = 30;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS:
+      rc = 56;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYOTHERMONTH:
+      rc = 60;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYTHREEMONTHS:
+    case MyMoneySchedule::OCCUR_QUARTERLY:
+      rc = 90;
+      break;
+    case MyMoneySchedule::OCCUR_EVERYFOURMONTHS:
+      rc = 120;
+      break;
+    case MyMoneySchedule::OCCUR_TWICEYEARLY:
+      rc = 180;
+      break;
+    case MyMoneySchedule::OCCUR_YEARLY:
+      rc = 360;
+      break;
+    default:
+      qWarning("Occurrence not supported by financial calculator");
   }
 
   return rc;
@@ -1160,41 +1222,41 @@ MyMoneySchedule::occurrenceE MyMoneySchedule::stringToOccurrence(const QString&
   MyMoneySchedule::occurrenceE occurrence = MyMoneySchedule::OCCUR_ANY;
   QString tmp = text.toLower();
 
-  if (tmp == i18nc("Occurs once", "Once").toLower())
+  if (tmp == i18nc("Frequency of schedule", "Once").toLower())
     occurrence = MyMoneySchedule::OCCUR_ONCE;
-  else if (tmp == i18nc("Occurs daily", "Daily").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Daily").toLower())
     occurrence = MyMoneySchedule::OCCUR_DAILY;
-  else if (tmp == i18nc("Occurs weekly", "Weekly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Weekly").toLower())
     occurrence = MyMoneySchedule::OCCUR_WEEKLY;
-  else if (tmp == i18n("Fortnightly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Fortnightly").toLower())
     occurrence = MyMoneySchedule::OCCUR_FORTNIGHTLY;
-  else if (tmp == i18n("Every other week").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every other week").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYOTHERWEEK;
-  else if (tmp == i18n("Every half month").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every half month").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYHALFMONTH;
-  else if (tmp == i18n("Every three weeks").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every three weeks").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYTHREEWEEKS;
-  else if (tmp == i18n("Every four weeks").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every four weeks").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYFOURWEEKS;
-  else if (tmp == i18n("Every thirty days").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every thirty days").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS;
-  else if (tmp == i18nc("Occurs monthly", "Monthly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Monthly").toLower())
     occurrence = MyMoneySchedule::OCCUR_MONTHLY;
-  else if (tmp == i18n("Every eight weeks").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every eight weeks").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS;
-  else if (tmp == i18n("Every two months").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every two months").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYOTHERMONTH;
-  else if (tmp == i18n("Every three months").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every three months").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYTHREEMONTHS;
-  else if (tmp == i18n("Quarterly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Quarterly").toLower())
     occurrence = MyMoneySchedule::OCCUR_QUARTERLY;
-  else if (tmp == i18n("Every four months").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every four months").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYFOURMONTHS;
-  else if (tmp == i18n("Twice yearly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Twice yearly").toLower())
     occurrence = MyMoneySchedule::OCCUR_TWICEYEARLY;
-  else if (tmp == i18nc("Occurs yearly", "Yearly").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Yearly").toLower())
     occurrence = MyMoneySchedule::OCCUR_YEARLY;
-  else if (tmp == i18n("Every other year").toLower())
+  else if (tmp == i18nc("Frequency of schedule", "Every other year").toLower())
     occurrence = MyMoneySchedule::OCCUR_EVERYOTHERYEAR;
 
   return occurrence;
@@ -1270,33 +1332,58 @@ void MyMoneySchedule::compoundToSimpleOccurrence(int& multiplier, occurrenceE& o
   if (occurrence == MyMoneySchedule::OCCUR_ONCE) { // Nothing to do
   } else if (occurrence == MyMoneySchedule::OCCUR_DAILY) {
     switch (multiplier) {
-    case 1: break;
-    case 30: newOcc = MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS; break;
+      case 1:
+        break;
+      case 30:
+        newOcc = MyMoneySchedule::OCCUR_EVERYTHIRTYDAYS;
+        break;
     }
   } else if (newOcc == MyMoneySchedule::OCCUR_WEEKLY) {
     switch (multiplier) {
-    case 1: break;
-    case 2: newOcc = MyMoneySchedule::OCCUR_EVERYOTHERWEEK; break;
-    case 3: newOcc = MyMoneySchedule::OCCUR_EVERYTHREEWEEKS; break;
-    case 4: newOcc = MyMoneySchedule::OCCUR_EVERYFOURWEEKS; break;
-    case 8: newOcc = MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS; break;
+      case 1:
+        break;
+      case 2:
+        newOcc = MyMoneySchedule::OCCUR_EVERYOTHERWEEK;
+        break;
+      case 3:
+        newOcc = MyMoneySchedule::OCCUR_EVERYTHREEWEEKS;
+        break;
+      case 4:
+        newOcc = MyMoneySchedule::OCCUR_EVERYFOURWEEKS;
+        break;
+      case 8:
+        newOcc = MyMoneySchedule::OCCUR_EVERYEIGHTWEEKS;
+        break;
     }
   } else if (occurrence == MyMoneySchedule::OCCUR_MONTHLY)
     switch (multiplier) {
-    case 1: break;
-    case 2: newOcc = MyMoneySchedule::OCCUR_EVERYOTHERMONTH; break;
-    case 3: newOcc = MyMoneySchedule::OCCUR_EVERYTHREEMONTHS; break;
-    case 4: newOcc = MyMoneySchedule::OCCUR_EVERYFOURMONTHS; break;
-    case 6: newOcc = MyMoneySchedule::OCCUR_TWICEYEARLY; break;
+      case 1:
+        break;
+      case 2:
+        newOcc = MyMoneySchedule::OCCUR_EVERYOTHERMONTH;
+        break;
+      case 3:
+        newOcc = MyMoneySchedule::OCCUR_EVERYTHREEMONTHS;
+        break;
+      case 4:
+        newOcc = MyMoneySchedule::OCCUR_EVERYFOURMONTHS;
+        break;
+      case 6:
+        newOcc = MyMoneySchedule::OCCUR_TWICEYEARLY;
+        break;
     }
   else if (occurrence == MyMoneySchedule::OCCUR_EVERYHALFMONTH)
     switch (multiplier) {
-    case 1: break;
+      case 1:
+        break;
     }
   else if (occurrence == MyMoneySchedule::OCCUR_YEARLY) {
     switch (multiplier) {
-    case 1: break;
-    case 2: newOcc = MyMoneySchedule::OCCUR_EVERYOTHERYEAR; break;
+      case 1:
+        break;
+      case 2:
+        newOcc = MyMoneySchedule::OCCUR_EVERYOTHERYEAR;
+        break;
     }
   }
   if (occurrence != newOcc) { // Changed to derived type
