@@ -438,7 +438,7 @@ void MyMoneySeqAccessMgr::addTransaction(MyMoneyTransaction& transaction, const
   // adjust the balance of all affected accounts
   for (it_s = transaction.splits().constBegin(); it_s != transaction.splits().constEnd(); ++it_s) {
     MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    acc.adjustBalance(*it_s);
+    adjustBalance(acc, *it_s);
     if (!skipAccountUpdate) {
       acc.touch();
       invalidateBalanceCache(acc.id());
@@ -447,6 +447,19 @@ void MyMoneySeqAccessMgr::addTransaction(MyMoneyTransaction& transaction, const
   }
 }
 
+void MyMoneySeqAccessMgr::adjustBalance(MyMoneyAccount& acc, const MyMoneySplit& split, bool reverse)
+{
+  // in case of an investment we can't just add or subtract the
+  // amount of the split since we don't know about stock splits.
+  // so in the case of those stocks, we simply recalculate the balance from scratch
+  if (acc.isInvest()) {
+    invalidateBalanceCache(acc.id());
+    acc.setBalance(balance(acc.id()));
+  } else {
+    acc.adjustBalance(split, reverse);
+  }
+}
+
 void MyMoneySeqAccessMgr::touch(void)
 {
   m_dirty = true;
@@ -568,17 +581,9 @@ void MyMoneySeqAccessMgr::modifyTransaction(const MyMoneyTransaction& transactio
   if (it_t == m_transactionList.end())
     throw new MYMONEYEXCEPTION("invalid transaction key");
 
-  // adjust account balances
   for (it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
     MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    acc.adjustBalance(*it_s, true);   // reverse the adjust operation (reverse = true)
-    acc.touch();
-    invalidateBalanceCache(acc.id());
-    m_accountList.modify(acc.id(), acc);
-  }
-  for (it_s = transaction.splits().begin(); it_s != transaction.splits().end(); ++it_s) {
-    MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    acc.adjustBalance(*it_s);
+    adjustBalance(acc, *it_s, true);
     acc.touch();
     invalidateBalanceCache(acc.id());
     m_accountList.modify(acc.id(), acc);
@@ -591,6 +596,15 @@ void MyMoneySeqAccessMgr::modifyTransaction(const MyMoneyTransaction& transactio
   QString newKey = transaction.uniqueSortKey();
   m_transactionList.insert(newKey, transaction);
   m_transactionKeys.modify(transaction.id(), newKey);
+
+  // adjust account balances
+  for (it_s = transaction.splits().begin(); it_s != transaction.splits().end(); ++it_s) {
+    MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
+    adjustBalance(acc, *it_s);
+    acc.touch();
+    invalidateBalanceCache(acc.id());
+    m_accountList.modify(acc.id(), acc);
+  }
 }
 
 void MyMoneySeqAccessMgr::reparentAccount(MyMoneyAccount &account, MyMoneyAccount& parent)
@@ -664,7 +678,7 @@ void MyMoneySeqAccessMgr::removeTransaction(const MyMoneyTransaction& transactio
   // to be updated after the removal of this transaction
   for (it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
     MyMoneyAccount acc = m_accountList[(*it_s).accountId()];
-    acc.adjustBalance(*it_s, true);  // reverse = true
+    adjustBalance(acc, *it_s, true);
     acc.touch();
     m_accountList.modify(acc.id(), acc);
     invalidateBalanceCache(acc.id());
@@ -875,14 +889,15 @@ const MyMoneyTransaction MyMoneySeqAccessMgr::transaction(const QString& account
 const MyMoneyMoney MyMoneySeqAccessMgr::balance(const QString& id, const QDate& date) const
 {
   MyMoneyMoney result(0);
-  MyMoneyAccount acc;
+  MyMoneyAccount acc = account(id);
   // if (date != QDate()) qDebug ("request balance for %s at %s", id.data(), date.toString(Qt::ISODate).toLatin1());
-  if (!date.isValid() && account(id).accountType() != MyMoneyAccount::Stock) {
-    if (m_accountList.find(id) != m_accountList.end())
+  if (!date.isValid() && !acc.isInvest()) {
+    if (m_accountList.find(id) != m_accountList.end()) {
       return m_accountList[id].balance();
+    }
     return MyMoneyMoney(0);
   }
-  if (m_balanceCache[id].valid == false || date != m_balanceCacheDate) {
+  if (m_balanceCache[id].valid == false || date != m_balanceCacheDate || acc.isInvest()) {
     QMap<QString, MyMoneyMoney> balances;
     QMap<QString, MyMoneyMoney>::ConstIterator it_b;
     if (date != m_balanceCacheDate) {
@@ -984,25 +999,54 @@ void MyMoneySeqAccessMgr::loadAccounts(const QMap<QString, MyMoneyAccount>& map)
 
 void MyMoneySeqAccessMgr::loadTransactions(const QMap<QString, MyMoneyTransaction>& map)
 {
-  m_transactionList = map;
 
   // now fill the key map and
   // identify the last used id
   QString lastId("");
   QMap<QString, QString> keys;
   QMap<QString, MyMoneyTransaction>::ConstIterator it_t;
-  for (it_t = map.begin(); it_t != map.end(); ++it_t) {
-    keys[(*it_t).id()] = it_t.key();
-    if ((*it_t).id() > lastId)
-      lastId = (*it_t).id();
+  QList<MyMoneyTransaction> duplicates;
+
+  for (it_t = map.constBegin(); it_t != map.constEnd(); ++it_t) {
+    if (keys.contains((*it_t).id())) {
+      qDebug("Duplicate detected for transaction '%s'", qPrintable((*it_t).id()));
+      duplicates << (*it_t);
+    } else {
+      keys[(*it_t).id()] = it_t.key();
+      if ((*it_t).id() > lastId)
+        lastId = (*it_t).id();
+    }
   }
-  m_transactionKeys = keys;
-
 
+  // keep track of hightes used ID so far
   int pos = lastId.indexOf(QRegExp("\\d+"), 0);
   if (pos != -1) {
     m_nextTransactionID = lastId.mid(pos).toInt();
   }
+
+  // process duplicates
+  QList<MyMoneyTransaction>::ConstIterator it_d;
+  if (duplicates.count() > 0) {
+    QMap<QString, MyMoneyTransaction> newMap;
+    newMap = map;
+    for (it_d = duplicates.constBegin(); it_d != duplicates.constEnd(); ++it_d) {
+      // remove old reference from map
+      newMap.remove((*it_d).uniqueSortKey());
+
+      // create transaction with new id
+      MyMoneyTransaction newTransaction(nextTransactionID(), *it_d);
+      QString key = newTransaction.uniqueSortKey();
+
+      newMap[key] = newTransaction;
+      keys[newTransaction.id()] = key;
+      qDebug("Duplicate got new id '%s'", qPrintable(newTransaction.id()));
+    }
+    m_transactionList = newMap;
+  } else {
+    m_transactionList = map;
+  }
+
+  m_transactionKeys = keys;
 }
 
 void MyMoneySeqAccessMgr::loadInstitutions(const QMap<QString, MyMoneyInstitution>& map)
