@@ -301,7 +301,7 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
       s << "  Enddate   = " << (*it_s).endDate().toString(Qt::ISODate) << "\n";
     else
       s << "  Enddate   = not specified\n";
-    s << "  Occurence = " << (*it_s).occurrenceToString() << "\n";
+    s << "  Occurence = " << (*it_s).occurrenceToString() << "\n"; // krazy:exclude=spelling
     s << "  OccurenceMultiplier = " << (*it_s).occurrenceMultiplier() << "\n";
     s << "  Type = " << MyMoneySchedule::scheduleTypeToString((*it_s).type()) << "\n";
     s << "  Paymenttype = " << MyMoneySchedule::paymentMethodToString((*it_s).paymentType()) << "\n";
@@ -416,21 +416,21 @@ const QString MyMoneyStorageDump::reconcileToString(MyMoneySplit::reconcileFlagE
   QString rc;
 
   switch (flag) {
-  case MyMoneySplit::NotReconciled:
-    rc = i18nc("Reconciliation status 'Not Reconciled'", "not reconciled");
-    break;
-  case MyMoneySplit::Cleared:
-    rc = i18nc("Reconciliation status 'Cleared'", "cleared");
-    break;
-  case MyMoneySplit::Reconciled:
-    rc = i18nc("Reconciliation status 'Reconciled'", "reconciled");
-    break;
-  case MyMoneySplit::Frozen:
-    rc = i18nc("Reconciliation status 'Frozen'", "frozen");
-    break;
-  default:
-    rc = i18nc("Reconciliation status unknown", "unknown");
-    break;
+    case MyMoneySplit::NotReconciled:
+      rc = i18nc("Reconciliation status 'Not Reconciled'", "not reconciled");
+      break;
+    case MyMoneySplit::Cleared:
+      rc = i18nc("Reconciliation status 'Cleared'", "cleared");
+      break;
+    case MyMoneySplit::Reconciled:
+      rc = i18nc("Reconciliation status 'Reconciled'", "reconciled");
+      break;
+    case MyMoneySplit::Frozen:
+      rc = i18nc("Reconciliation status 'Frozen'", "frozen");
+      break;
+    default:
+      rc = i18nc("Reconciliation status unknown", "unknown");
+      break;
   }
   return rc;
 }
