@@ -27,7 +27,6 @@
 // ----------------------------------------------------------------------------
 // QT Includes
 
-#include <QMessageBox>
 #include <QLayout>
 #include <QRadioButton>
 #include <QStringList>
@@ -38,20 +37,20 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kgenericfactory.h>
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <kmenu.h>
-#include <kiconloader.h>
-#include <kguiitem.h>
-#include <klineedit.h>
-#include <keditlistbox.h>
-#include <kcombobox.h>
-#include <kconfig.h>
+#include <KLocale>
+#include <KMessageBox>
+#include <KGenericFactory>
+#include <KAction>
+#include <KActionCollection>
+#include <KGlobal>
+#include <KStandardDirs>
+#include <KMenu>
+#include <KIconLoader>
+#include <KGuiItem>
+#include <KLineEdit>
+#include <KEditListBox>
+#include <KComboBox>
+#include <KConfig>
 
 // ----------------------------------------------------------------------------
 // Library Includes
@@ -91,24 +90,24 @@ public:
       KConfigGroup grp = cfg->group("Proxy Settings");
       int type = grp.readEntry("ProxyType", 0);
       switch (type) {
-      case 0: // no proxy
-        break;
+        case 0: // no proxy
+          break;
 
-      case 1: // manual specified
-        proxy = grp.readEntry("httpsProxy");
-        qDebug("KDE https proxy setting is '%s'", qPrintable(proxy));
-        if (exp.exactMatch(proxy) != -1) {
-          proxy = exp.cap(2);
-          qDebug("Setting GWEN_PROXY to '%s'", qPrintable(proxy));
-          if (setenv("GWEN_PROXY", qPrintable(proxy), 1) == -1) {
-            qDebug("Unable to setup GWEN_PROXY");
+        case 1: // manual specified
+          proxy = grp.readEntry("httpsProxy");
+          qDebug("KDE https proxy setting is '%s'", qPrintable(proxy));
+          if (exp.exactMatch(proxy) != -1) {
+            proxy = exp.cap(2);
+            qDebug("Setting GWEN_PROXY to '%s'", qPrintable(proxy));
+            if (setenv("GWEN_PROXY", qPrintable(proxy), 1) == -1) {
+              qDebug("Unable to setup GWEN_PROXY");
+            }
           }
-        }
-        break;
+          break;
 
-      default: // other currently not supported
-        qDebug("KDE proxy setting of type %d not supported", type);
-        break;
+        default: // other currently not supported
+          qDebug("KDE proxy setting of type %d not supported", type);
+          break;
       }
       delete cfg;
     }
@@ -234,8 +233,8 @@ QWidget* KBankingPlugin::accountConfigTab(const MyMoneyAccount& acc, QString& na
     m_accountSettings = new KBAccountSettings(acc, 0);
     m_accountSettings->m_usePayeeAsIsButton->setChecked(true);
     m_accountSettings->m_transactionDownload->setChecked(kvp.value("kbanking-txn-download") != "no");
-    m_accountSettings->m_preferredJobMethod->setCurrentItem(kvp.value("kbanking-jobexec"));
-    m_accountSettings->m_preferredStatementDate->setCurrentItem(kvp.value("kbanking-statementDate"));
+    m_accountSettings->m_preferredJobMethod->setCurrentIndex(kvp.value("kbanking-jobexec").toInt());
+    m_accountSettings->m_preferredStatementDate->setCurrentIndex(kvp.value("kbanking-statementDate").toInt());
     if (!kvp.value("kbanking-payee-regexp").isEmpty()) {
       m_accountSettings->m_extractPayeeButton->setChecked(true);
       m_accountSettings->m_payeeRegExpEdit->setText(kvp.value("kbanking-payee-regexp"));
@@ -430,17 +429,14 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
     /* get AqBanking account */
     ba = AB_BANKING_GETACCOUNTBYALIAS(m_kbanking->getCInterface(), acc.id().toUtf8().data());
     if (!ba) {
-      QMessageBox::critical(0,
-                            i18n("Account Not Mapped"),
-                            i18n("<qt>"
-                                 "<p>"
-                                 "The given application account <b>%1</b> "
-                                 "has not been mapped to an online "
-                                 "account."
-                                 "</p>"
-                                 "</qt>",
-                                 acc.name()),
-                            QMessageBox::Ok, Qt::NoButton);
+      KMessageBox::error(0,
+                         i18n("<qt>"
+                              "The given application account <b>%1</b> "
+                              "has not been mapped to an online "
+                              "account."
+                              "</qt>",
+                              acc.name()),
+                         i18n("Account Not Mapped"));
       // clear the connection between the KMyMoney account
       // and the AqBanking equivalent
       setupAccountReference(acc, 0);
@@ -455,13 +451,12 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
         rv = AB_BANKING_JOB_CHECKAVAILABILITY(job);
         if (rv) {
           DBG_ERROR(0, "Job \"GetTransactions\" is not available (%d)", rv);
-          QMessageBox::critical(0,
-                                i18n("Job not Available"),
-                                i18n("<qt>"
-                                     "The update job is not supported by the "
-                                     "bank/account/backend.\n"
-                                     "</qt>"),
-                                i18n("Dismiss"), QString());
+          KMessageBox::error(0,
+                             i18n("<qt>"
+                                  "The update job is not supported by the "
+                                  "bank/account/backend.\n"
+                                  "</qt>"),
+                             i18n("Job not Available"));
           AB_Job_free(job);
           job = 0;
         }
@@ -493,17 +488,17 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
 
           int dateOption = acc.onlineBankingSettings().value("kbanking-statementDate").toInt();
           switch (dateOption) {
-          case 0: // Ask user
-            break;
-          case 1: // No date
-            qd = QDate();
-            break;
-          case 2: // Last download
-            qd = lastUpdate;
-            break;
-          case 3: // First possible
-            // qd is already setup
-            break;
+            case 0: // Ask user
+              break;
+            case 1: // No date
+              qd = QDate();
+              break;
+            case 2: // Last download
+              qd = lastUpdate;
+              break;
+            case 3: // First possible
+              // qd is already setup
+              break;
           }
 
           // the pick start date option dialog is needed in
@@ -534,12 +529,11 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
           AB_Job_free(job);
           if (rv) {
             DBG_ERROR(0, "Error %d", rv);
-            QMessageBox::critical(0,
-                                  i18n("Error"),
-                                  i18n("<qt>"
-                                       "Could not enqueue the job.\n"
-                                       "</qt>"),
-                                  i18n("Dismiss"), QString());
+            KMessageBox::error(0,
+                               i18n("<qt>"
+                                    "Could not enqueue the job.\n"
+                                    "</qt>"),
+                               i18n("Error"));
           }
         }
       }
@@ -555,12 +549,11 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
       AB_Job_free(job);
       if (rv) {
         DBG_ERROR(0, "Error %d", rv);
-        QMessageBox::critical(0,
-                              i18n("Error"),
-                              i18n("<qt>"
-                                   "Could not enqueue the job.\n"
-                                   "</qt>"),
-                              i18n("Dismiss"), QString());
+        KMessageBox::error(0,
+                           i18n("<qt>"
+                                "Could not enqueue the job.\n"
+                                "</qt>"),
+                           i18n("Error"));
       }
     }
 
@@ -585,17 +578,17 @@ bool KBankingPlugin::updateAccount(const MyMoneyAccount& acc, bool moreAccounts)
       KMessageBox::ButtonCode result = KMessageBox::Cancel;
       if (!moreAccounts) {
         switch (acc.onlineBankingSettings().value("kbanking-jobexec").toInt()) {
-        case 1:
-          result = KMessageBox::Yes;
-          break;
-        case 2:
-          result = KMessageBox::No;
-          break;
-        default:
-          result = static_cast<KMessageBox::ButtonCode>(KMessageBox::questionYesNo(0,
-                   i18n("Do you want to execute or queue this job in the outbox?"),
-                   i18n("Execution"), executeButton, queueButton));
-          break;
+          case 1:
+            result = KMessageBox::Yes;
+            break;
+          case 2:
+            result = KMessageBox::No;
+            break;
+          default:
+            result = static_cast<KMessageBox::ButtonCode>(KMessageBox::questionYesNo(0,
+                     i18n("Do you want to execute or queue this job in the outbox?"),
+                     i18n("Execution"), executeButton, queueButton));
+            break;
         }
       } else {
         result = KMessageBox::No;
@@ -911,26 +904,26 @@ bool KMyMoneyBanking::importAccountInfo(AB_IMEXPORTER_ACCOUNTINFO *ai,
 
   // account type
   switch (AB_ImExporterAccountInfo_GetType(ai)) {
-  case AB_AccountType_Bank:
-    ks.m_eType = MyMoneyStatement::etSavings;
-    break;
-  case AB_AccountType_CreditCard:
-    ks.m_eType = MyMoneyStatement::etCreditCard;
-    break;
-  case AB_AccountType_Checking:
-    ks.m_eType = MyMoneyStatement::etCheckings;
-    break;
-  case AB_AccountType_Savings:
-    ks.m_eType = MyMoneyStatement::etSavings;
-    break;
-  case AB_AccountType_Investment:
-    ks.m_eType = MyMoneyStatement::etInvestment;
-    break;
-  case AB_AccountType_Cash:
-    ks.m_eType = MyMoneyStatement::etNone;
-    break;
-  default:
-    ks.m_eType = MyMoneyStatement::etNone;
+    case AB_AccountType_Bank:
+      ks.m_eType = MyMoneyStatement::etSavings;
+      break;
+    case AB_AccountType_CreditCard:
+      ks.m_eType = MyMoneyStatement::etCreditCard;
+      break;
+    case AB_AccountType_Checking:
+      ks.m_eType = MyMoneyStatement::etCheckings;
+      break;
+    case AB_AccountType_Savings:
+      ks.m_eType = MyMoneyStatement::etSavings;
+      break;
+    case AB_AccountType_Investment:
+      ks.m_eType = MyMoneyStatement::etInvestment;
+      break;
+    case AB_AccountType_Cash:
+      ks.m_eType = MyMoneyStatement::etNone;
+      break;
+    default:
+      ks.m_eType = MyMoneyStatement::etNone;
   }
 
   // account status
@@ -978,11 +971,9 @@ bool KMyMoneyBanking::importAccountInfo(AB_IMEXPORTER_ACCOUNTINFO *ai,
 
   // import them
   if (!m_parent->importStatement(ks)) {
-    if (QMessageBox::critical(0,
-                              i18n("Critical Error"),
-                              i18n("Error importing statement."),
-                              i18n("Continue"),
-                              i18n("Abort"), 0, 0) != 0) {
+    if (KMessageBox::warningYesNo(0,
+                                  i18n("Error importing statement. Do you want to continue?"),
+                                  i18n("Critical Error")) == KMessageBox::No) {
       DBG_ERROR(0, "User aborted");
       return false;
     }
