@@ -31,6 +31,7 @@
 #include <QRegExp>
 #include <QByteArray>
 #include <QList>
+#include <QApplication>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
@@ -38,6 +39,8 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kcombobox.h>
+#include <kpassworddialog.h>
+#include <KWallet/Wallet>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -48,6 +51,8 @@
 #include <mymoneykeyvaluecontainer.h>
 #include <kdeversion.h>
 
+using KWallet::Wallet;
+
 OfxHeaderVersion::OfxHeaderVersion(KComboBox* combo, const QString& headerVersion) :
     m_combo(combo)
 {
@@ -154,7 +159,32 @@ QString MyMoneyOfxConnector::username(void) const
 }
 QString MyMoneyOfxConnector::password(void) const
 {
-  return m_fiSettings.value("password");
+  // if we don't find a password in the wallet, we use the old method
+  // and retrieve it from the settings stored in the KMyMoney data storage.
+  // in case we don't have a password on file, we ask the user
+  QString key = OFX_PASSWORD_KEY(m_fiSettings.value("url"), m_fiSettings.value("uniqueId"));
+  QString pwd = m_fiSettings.value("password");
+
+  // make sure, we have a reference to an active window, otherwise use 0 as ID
+  WId winId = 0;
+  if (qApp->activeWindow())
+    winId = qApp->activeWindow()->winId();
+
+  // now check for the wallet
+  Wallet *wallet = Wallet::openWallet(Wallet::NetworkWallet(), winId, Wallet::Synchronous);
+  if (wallet
+      && !Wallet::keyDoesNotExist(Wallet::NetworkWallet(), Wallet::PasswordFolder(), key)) {
+    wallet->setFolder(Wallet::PasswordFolder());
+    wallet->readPassword(key, pwd);
+  }
+
+  if (pwd.isEmpty()) {
+    KPasswordDialog dlg(0);
+    dlg.setPrompt(i18n("Enter your password"));
+    if (dlg.exec())
+      pwd = dlg.password();
+  }
+  return pwd;
 }
 QString MyMoneyOfxConnector::accountnum(void) const
 {
@@ -199,17 +229,17 @@ OfxAccountData::AccountType MyMoneyOfxConnector::accounttype(void) const
     result = OfxAccountData::OFX_INVESTMENT;
   else {
     switch (m_account.accountType()) {
-    case MyMoneyAccount::Investment:
-      result = OfxAccountData::OFX_INVESTMENT;
-      break;
-    case MyMoneyAccount::CreditCard:
-      result = OfxAccountData::OFX_CREDITCARD;
-      break;
-    case MyMoneyAccount::Savings:
-      result = OfxAccountData::OFX_SAVINGS;
-      break;
-    default:
-      break;
+      case MyMoneyAccount::Investment:
+        result = OfxAccountData::OFX_INVESTMENT;
+        break;
+      case MyMoneyAccount::CreditCard:
+        result = OfxAccountData::OFX_CREDITCARD;
+        break;
+      case MyMoneyAccount::Savings:
+        result = OfxAccountData::OFX_SAVINGS;
+        break;
+      default:
+        break;
     }
   }
 
@@ -239,14 +269,14 @@ AccountType MyMoneyOfxConnector::accounttype(void) const
   AccountType result = OFX_BANK_ACCOUNT;
 
   switch (m_account.accountType()) {
-  case MyMoneyAccount::Investment:
-    result = OFX_INVEST_ACCOUNT;
-    break;
-  case MyMoneyAccount::CreditCard:
-    result = OFX_CREDITCARD_ACCOUNT;
-    break;
-  default:
-    break;
+    case MyMoneyAccount::Investment:
+      result = OFX_INVEST_ACCOUNT;
+      break;
+    case MyMoneyAccount::CreditCard:
+      result = OFX_CREDITCARD_ACCOUNT;
+      break;
+    default:
+      break;
   }
 
   // This is a bit of a personalized hack.  Sometimes we may want to override the
@@ -329,14 +359,16 @@ const QByteArray MyMoneyOfxConnector::statementRequest(void) const
   account.type = accounttype();
 #endif
 
-  char* szrequest = libofx_request_statement(&fi, &account, QDateTime(statementStartDate()).toTime_t());
-  QString request = szrequest;
-  // remove the trailing zero
-  QByteArray result = request.toUtf8();
-  result.truncate(result.size() - 1);
-  free(szrequest);
+  QByteArray result;
+  if (fi.userpass[0]) {
+    char *szrequest = libofx_request_statement(&fi, &account, QDateTime(statementStartDate()).toTime_t());
+    QString request = szrequest;
+    // remove the trailing zero
+    result = request.toUtf8();
+    result.truncate(result.size() - 1);
+    free(szrequest);
+  }
 
-  QString msg(result);
   return result;
 }
 
