@@ -47,6 +47,7 @@
 #include "kmymoneyglobalsettings.h"
 #include "kmymoneyutils.h"
 #include "mymoneyforecast.h"
+#include <mymoneyprice.h>
 
 namespace reports
 {
@@ -876,66 +877,66 @@ void PivotTable::calculateBudgetMapping(void)
 
         // based on the kind of budget it is, deal accordingly
         switch ((*it_bacc).budgetLevel()) {
-        case MyMoneyBudget::AccountGroup::eYearly:
-          // divide the single yearly value by 12 and place it in each column
-          value /= MyMoneyMoney(12, 1);
-        case MyMoneyBudget::AccountGroup::eNone:
-        case MyMoneyBudget::AccountGroup::eMax:
-        case MyMoneyBudget::AccountGroup::eMonthly:
-          // place the single monthly value in each column of the report
-          // only add the value if columns are monthly or longer
-          if (m_config_f.columnType() == MyMoneyReport::eBiMonths
-              || m_config_f.columnType() == MyMoneyReport::eMonths
-              || m_config_f.columnType() == MyMoneyReport::eYears
-              || m_config_f.columnType() == MyMoneyReport::eQuarters) {
-            QDate budgetDate = budget.budgetStart();
-            while (column < m_numColumns && budget.budgetStart().addYears(1) > budgetDate) {
-              //only show budget values if the budget year and the column date match
-              //no currency conversion is done here because that is done for all columns later
-              if (budgetDate > columnDate(column)) {
-                ++column;
-              } else {
-                if (budgetDate >= m_beginDate.addDays(-m_beginDate.day() + 1)
-                    && budgetDate <= m_endDate.addDays(m_endDate.daysInMonth() - m_endDate.day())
-                    && budgetDate > (columnDate(column).addMonths(-m_config_f.columnType()))) {
-                  assignCell(outergroup, splitAccount, column, value, true /*budget*/);
+          case MyMoneyBudget::AccountGroup::eYearly:
+            // divide the single yearly value by 12 and place it in each column
+            value /= MyMoneyMoney(12, 1);
+          case MyMoneyBudget::AccountGroup::eNone:
+          case MyMoneyBudget::AccountGroup::eMax:
+          case MyMoneyBudget::AccountGroup::eMonthly:
+            // place the single monthly value in each column of the report
+            // only add the value if columns are monthly or longer
+            if (m_config_f.columnType() == MyMoneyReport::eBiMonths
+                || m_config_f.columnType() == MyMoneyReport::eMonths
+                || m_config_f.columnType() == MyMoneyReport::eYears
+                || m_config_f.columnType() == MyMoneyReport::eQuarters) {
+              QDate budgetDate = budget.budgetStart();
+              while (column < m_numColumns && budget.budgetStart().addYears(1) > budgetDate) {
+                //only show budget values if the budget year and the column date match
+                //no currency conversion is done here because that is done for all columns later
+                if (budgetDate > columnDate(column)) {
+                  ++column;
+                } else {
+                  if (budgetDate >= m_beginDate.addDays(-m_beginDate.day() + 1)
+                      && budgetDate <= m_endDate.addDays(m_endDate.daysInMonth() - m_endDate.day())
+                      && budgetDate > (columnDate(column).addMonths(-m_config_f.columnType()))) {
+                    assignCell(outergroup, splitAccount, column, value, true /*budget*/);
+                  }
+                  budgetDate = budgetDate.addMonths(1);
                 }
-                budgetDate = budgetDate.addMonths(1);
               }
             }
-          }
-          break;
-        case MyMoneyBudget::AccountGroup::eMonthByMonth:
-          // place each value in the appropriate column
-          // budget periods are supposed to come in order just like columns
-        {
-          QMap<QDate, MyMoneyBudget::PeriodGroup>::const_iterator it_period = periods.begin();
-          while (it_period != periods.end() && column < m_numColumns) {
-            if ((*it_period).startDate() > columnDate(column)) {
-              ++column;
-            } else {
-              switch (m_config_f.columnType()) {
-              case MyMoneyReport::eYears:
-              case MyMoneyReport::eBiMonths:
-              case MyMoneyReport::eQuarters:
-              case MyMoneyReport::eMonths: {
-                if ((*it_period).startDate() >= m_beginDate.addDays(-m_beginDate.day() + 1)
-                    && (*it_period).startDate() <= m_endDate.addDays(m_endDate.daysInMonth() - m_endDate.day())
-                    && (*it_period).startDate() > (columnDate(column).addMonths(-m_config_f.columnType()))) {
-                  //no currency conversion is done here because that is done for all columns later
-                  value = (*it_period).amount() * reverse;
-                  assignCell(outergroup, splitAccount, column, value, true /*budget*/);
+            break;
+          case MyMoneyBudget::AccountGroup::eMonthByMonth:
+            // place each value in the appropriate column
+            // budget periods are supposed to come in order just like columns
+            {
+              QMap<QDate, MyMoneyBudget::PeriodGroup>::const_iterator it_period = periods.begin();
+              while (it_period != periods.end() && column < m_numColumns) {
+                if ((*it_period).startDate() > columnDate(column)) {
+                  ++column;
+                } else {
+                  switch (m_config_f.columnType()) {
+                    case MyMoneyReport::eYears:
+                    case MyMoneyReport::eBiMonths:
+                    case MyMoneyReport::eQuarters:
+                    case MyMoneyReport::eMonths: {
+                        if ((*it_period).startDate() >= m_beginDate.addDays(-m_beginDate.day() + 1)
+                            && (*it_period).startDate() <= m_endDate.addDays(m_endDate.daysInMonth() - m_endDate.day())
+                            && (*it_period).startDate() > (columnDate(column).addMonths(-m_config_f.columnType()))) {
+                          //no currency conversion is done here because that is done for all columns later
+                          value = (*it_period).amount() * reverse;
+                          assignCell(outergroup, splitAccount, column, value, true /*budget*/);
+                        }
+                        ++it_period;
+                        break;
+                      }
+                    default:
+                      break;
+                  }
                 }
-                ++it_period;
-                break;
-              }
-              default:
-                break;
               }
+              break;
             }
-          }
-          break;
-        }
         }
       }
       ++it_bacc;
@@ -1280,14 +1281,38 @@ QString PivotTable::renderCSV(void) const
   result += i18n("Account");
 
   int column = 1;
-  while (column < m_numColumns)
+  while (column < m_numColumns) {
     result += QString(",%1").arg(QString(m_columnHeadings[column++]));
+    if (m_rowTypeList.size() > 1) {
+      QString separator;
+      separator = separator.fill(',', m_rowTypeList.size() - 1);
+      result += separator;
+    }
+  }
 
+  //show total columns
   if (m_config_f.isShowingRowTotals())
     result += QString(",%1").arg(i18nc("Total balance", "Total"));
 
   result += '\n';
 
+  // Row Type Header
+  if (m_rowTypeList.size() > 1) {
+    int column = 1;
+    while (column < m_numColumns) {
+      for (int i = 0; i < m_rowTypeList.size(); ++i) {
+        result += QString(",%1").arg(m_columnTypeHeaderList[i]);
+      }
+      column++;
+    }
+    if (m_config_f.isShowingRowTotals()) {
+      for (int i = 0; i < m_rowTypeList.size(); ++i) {
+        result += QString(",%1").arg(m_columnTypeHeaderList[i]);
+      }
+    }
+    result += '\n';
+  }
+
   int fraction = MyMoneyFile::instance()->baseCurrency().smallestAccountFraction();
 
   //
@@ -1862,22 +1887,22 @@ void PivotTable::calculateBudgetDiff(void)
       while (it_row != (*it_innergroup).end()) {
         int column = 1;
         switch (it_row.key().accountGroup()) {
-        case MyMoneyAccount::Income:
-        case MyMoneyAccount::Asset:
-          while (column < m_numColumns) {
-            it_row.value()[eBudgetDiff][column] = it_row.value()[eActual][column] - it_row.value()[eBudget][column];
-            ++column;
-          }
-          break;
-        case MyMoneyAccount::Expense:
-        case MyMoneyAccount::Liability:
-          while (column < m_numColumns) {
-            it_row.value()[eBudgetDiff][column] = it_row.value()[eBudget][column] - it_row.value()[eActual][column];
-            ++column;
-          }
-          break;
-        default:
-          break;
+          case MyMoneyAccount::Income:
+          case MyMoneyAccount::Asset:
+            while (column < m_numColumns) {
+              it_row.value()[eBudgetDiff][column] = it_row.value()[eActual][column] - it_row.value()[eBudget][column];
+              ++column;
+            }
+            break;
+          case MyMoneyAccount::Expense:
+          case MyMoneyAccount::Liability:
+            while (column < m_numColumns) {
+              it_row.value()[eBudgetDiff][column] = it_row.value()[eBudget][column] - it_row.value()[eActual][column];
+              ++column;
+            }
+            break;
+          default:
+            break;
         }
         ++it_row;
       }
@@ -1891,9 +1916,7 @@ void PivotTable::calculateBudgetDiff(void)
 void PivotTable::calculateForecast(void)
 {
   //setup forecast
-  MyMoneyForecast forecast;
-
-  //setup forecast settings
+  MyMoneyForecast forecast = KMyMoneyGlobalSettings::forecast();
 
   //since this is a net worth forecast we want to include all account even those that are not in use
   forecast.setIncludeUnusedAccounts(true);
@@ -2050,28 +2073,28 @@ void PivotTable::calculateMovingAverage(void)
 
             //set the right start date depending on the column type
             switch (m_config_f.columnType()) {
-            case MyMoneyReport::eYears: {
-              averageStart = QDate(columnDate(column).year(), 1, 1);
-              break;
-            }
-            case MyMoneyReport::eBiMonths: {
-              averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1).addMonths(-1);
-              break;
-            }
-            case MyMoneyReport::eQuarters: {
-              averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1).addMonths(-1);
-              break;
-            }
-            case MyMoneyReport::eMonths: {
-              averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1);
-              break;
-            }
-            case MyMoneyReport::eWeeks: {
-              averageStart = columnDate(column).addDays(-columnDate(column).dayOfWeek() + 1);
-              break;
-            }
-            default:
-              break;
+              case MyMoneyReport::eYears: {
+                  averageStart = QDate(columnDate(column).year(), 1, 1);
+                  break;
+                }
+              case MyMoneyReport::eBiMonths: {
+                  averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1).addMonths(-1);
+                  break;
+                }
+              case MyMoneyReport::eQuarters: {
+                  averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1).addMonths(-1);
+                  break;
+                }
+              case MyMoneyReport::eMonths: {
+                  averageStart = QDate(columnDate(column).year(), columnDate(column).month(), 1);
+                  break;
+                }
+              case MyMoneyReport::eWeeks: {
+                  averageStart = columnDate(column).addDays(-columnDate(column).dayOfWeek() + 1);
+                  break;
+                }
+              default:
+                break;
             }
 
             //gather the actual data and calculate the average
@@ -2105,7 +2128,13 @@ void PivotTable::calculateMovingAverage(void)
 
 void PivotTable::fillBasePriceUnit(ERowType rowType)
 {
-  //go through the data and add forecast
+  MyMoneyFile* file = MyMoneyFile::instance();
+  QString baseCurrencyId = file->baseCurrency().id();
+
+  //get the first price date for securities
+  QMap<QString, QDate> securityDates = securityFirstPrice();
+
+  //go through the data
   PivotGrid::iterator it_outergroup = m_grid.begin();
   while (it_outergroup != m_grid.end()) {
     PivotOuterGroup::iterator it_innergroup = (*it_outergroup).begin();
@@ -2113,9 +2142,26 @@ void PivotTable::fillBasePriceUnit(ERowType rowType)
       PivotInnerGroup::iterator it_row = (*it_innergroup).begin();
       while (it_row != (*it_innergroup).end()) {
         int column = 1;
+
+        //if it is a base currency fill all the values
+        bool firstPriceExists = false;
+        if (it_row.key().currencyId() == baseCurrencyId) {
+          firstPriceExists = true;
+        }
+
         while (column < m_numColumns) {
-          //insert a unit of currency for each account
-          it_row.value()[rowType][column] = MyMoneyMoney(1, 1);
+          //check whether the date for that column is on or after the first price
+          if (!firstPriceExists
+              && securityDates.contains(it_row.key().currencyId())
+              && columnDate(column) >= securityDates.value(it_row.key().currencyId())) {
+            firstPriceExists = true;
+          }
+
+          //only add the dummy value if there is a price for that date
+          if (firstPriceExists) {
+            //insert a unit of currency for each account
+            it_row.value()[rowType][column] = MyMoneyMoney(1, 1);
+          }
           ++column;
         }
         ++it_row;
@@ -2126,6 +2172,39 @@ void PivotTable::fillBasePriceUnit(ERowType rowType)
   }
 }
 
+QMap<QString, QDate> PivotTable::securityFirstPrice()
+{
+  MyMoneyFile* file = MyMoneyFile::instance();
+  MyMoneyPriceList priceList = file->priceList();
+  QMap<QString, QDate> securityPriceDate;
+
+  MyMoneyPriceList::const_iterator prices_it;
+  for (prices_it = priceList.constBegin(); prices_it != priceList.constEnd(); ++prices_it) {
+    MyMoneyPrice firstPrice = (*((*prices_it).constBegin()));
+
+    //check the security in the from field
+    //if it is there, check if it is older
+    if (securityPriceDate.contains(firstPrice.from())) {
+      if (securityPriceDate.value(firstPrice.from()) > firstPrice.date()) {
+        securityPriceDate[firstPrice.from()] = firstPrice.date();
+      }
+    } else {
+      securityPriceDate.insert(firstPrice.from(), firstPrice.date());
+    }
+
+    //check the security in the to field
+    //if it is there, check if it is older
+    if (securityPriceDate.contains(firstPrice.to())) {
+      if (securityPriceDate.value(firstPrice.to()) > firstPrice.date()) {
+        securityPriceDate[firstPrice.to()] = firstPrice.date();
+      }
+    } else {
+      securityPriceDate.insert(firstPrice.to(), firstPrice.date());
+    }
+  }
+  return securityPriceDate;
+}
+
 void PivotTable::includeInvestmentSubAccounts()
 {
   // if we're not in expert mode, we need to make sure
