@@ -49,8 +49,10 @@
 #include "models.h"
 
 KAccountsView::KAccountsView(QWidget *parent) :
-    KAccountsViewDecl(parent)
+    QWidget(parent)
 {
+  setupUi(this);
+
   // setup icons for collapse and expand button
   KGuiItem collapseGuiItem("",
                            KIcon("zoom-out"),
@@ -88,6 +90,7 @@ KAccountsView::KAccountsView(QWidget *parent) :
 
   connect(m_filterProxyModel, SIGNAL(unusedIncomeExpenseAccountHidden()), this, SLOT(slotUnusedIncomeExpenseAccountHidden()));
 
+  m_accountTree->setConfigGroupName("KAccountsView");
   m_accountTree->setAlternatingRowColors(true);
   m_accountTree->setIconSize(QSize(22, 22));
   m_accountTree->setSortingEnabled(true);
@@ -131,10 +134,10 @@ KAccountsView::KAccountsView(QWidget *parent) :
   // connect the two buttons to all required slots
   connect(m_collapseButton, SIGNAL(clicked()), this, SLOT(slotExpandCollapse()));
   connect(m_collapseButton, SIGNAL(clicked()), m_accountTree, SLOT(collapseAll()));
-  connect(m_collapseButton, SIGNAL(clicked()), m_filterProxyModel, SLOT(collapseAll()));
+  connect(m_accountTree, SIGNAL(collapsedAll()), m_filterProxyModel, SLOT(collapseAll()));
   connect(m_expandButton, SIGNAL(clicked()), this, SLOT(slotExpandCollapse()));
   connect(m_expandButton, SIGNAL(clicked()), m_accountTree, SLOT(expandAll()));
-  connect(m_expandButton, SIGNAL(clicked()), m_filterProxyModel, SLOT(expandAll()));
+  connect(m_accountTree, SIGNAL(expandedAll()), m_filterProxyModel, SLOT(expandAll()));
 }
 
 KAccountsView::~KAccountsView()
@@ -177,48 +180,48 @@ void KAccountsView::slotTabCurrentChanged(QWidget* _tab)
   loadAccounts(tab);
 
   switch (tab) {
-  case ListView:
-    // update the hint if categories are hidden
-    m_hiddenCategories->setVisible(m_haveUnusedCategories);
-    break;
+    case ListView:
+      // update the hint if categories are hidden
+      m_hiddenCategories->setVisible(m_haveUnusedCategories);
+      break;
 
-  case IconView:
-    m_hiddenCategories->hide();
-    break;
+    case IconView:
+      m_hiddenCategories->hide();
+      break;
 
-  default:
-    break;
+    default:
+      break;
   }
 
   QListWidgetItem* iconItem = selectedIcon();
 
   emit selectObject(MyMoneyAccount());
   switch (static_cast<AccountsViewTab>(m_tab->currentIndex())) {
-  case ListView: {
-    QModelIndexList selectedIndexes = m_accountTree->selectionModel()->selectedIndexes();
-    if (!selectedIndexes.empty()) {
-      QVariant data = m_accountTree->model()->data(selectedIndexes.front(), AccountsModel::AccountRole);
-      if (data.isValid()) {
-        emit selectObject(data.value<MyMoneyAccount>());
+    case ListView: {
+        QModelIndexList selectedIndexes = m_accountTree->selectionModel()->selectedIndexes();
+        if (!selectedIndexes.empty()) {
+          QVariant data = m_accountTree->model()->data(selectedIndexes.front(), AccountsModel::AccountRole);
+          if (data.isValid()) {
+            emit selectObject(data.value<MyMoneyAccount>());
+          }
+        }
       }
-    }
-  }
-  break;
+      break;
 
-  case IconView:
-    if (iconItem) {
-      emit selectObject((iconItem->data(Qt::UserRole)).value<MyMoneyAccount>());
-    }
-    break;
+    case IconView:
+      if (iconItem) {
+        emit selectObject((iconItem->data(Qt::UserRole)).value<MyMoneyAccount>());
+      }
+      break;
 
-  default:
-    break;
+    default:
+      break;
   }
 }
 
 void KAccountsView::showEvent(QShowEvent * event)
 {
-  KAccountsViewDecl::showEvent(event);
+  QWidget::showEvent(event);
   slotTabCurrentChanged(m_tab->currentWidget());
 }
 
@@ -226,14 +229,14 @@ void KAccountsView::loadAccounts(AccountsViewTab tab)
 {
   if (m_needReload[tab]) {
     switch (tab) {
-    case ListView:
-      loadListView();
-      break;
-    case IconView:
-      loadIconGroups();
-      break;
-    default:
-      break;
+      case ListView:
+        loadListView();
+        break;
+      case IconView:
+        loadIconGroups();
+        break;
+      default:
+        break;
     }
     m_needReload[tab] = false;
   }
