@@ -538,17 +538,17 @@ void KGlobalLedgerView::loadView(void)
 
     if (isReconciliationAccount()) {
       switch (m_register->primarySortKey()) {
-      case KMyMoneyRegister::PostDateSort:
-        statement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Details"));
-        m_register->sortItems();
-        break;
-      case KMyMoneyRegister::TypeSort:
-        dStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Deposit Details"));
-        pStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Payment, reconciliationDate, i18n("Statement Payment Details"));
-        m_register->sortItems();
-        break;
-      default:
-        break;
+        case KMyMoneyRegister::PostDateSort:
+          statement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Details"));
+          m_register->sortItems();
+          break;
+        case KMyMoneyRegister::TypeSort:
+          dStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Deposit, reconciliationDate, i18n("Statement Deposit Details"));
+          pStatement = new KMyMoneyRegister::StatementGroupMarker(m_register, KMyMoneyRegister::Payment, reconciliationDate, i18n("Statement Payment Details"));
+          m_register->sortItems();
+          break;
+        default:
+          break;
       }
     }
 
@@ -1035,11 +1035,11 @@ void KGlobalLedgerView::slotNewTransaction(void)
 void KGlobalLedgerView::setupDefaultAction(void)
 {
   switch (m_account.accountType()) {
-    // TODO if we want a different action for different account types
-    //      we can add cases here
-  default:
-    d->m_action = KMyMoneyRegister::ActionWithdrawal;
-    break;
+      // TODO if we want a different action for different account types
+      //      we can add cases here
+    default:
+      d->m_action = KMyMoneyRegister::ActionWithdrawal;
+      break;
   }
 }
 
@@ -1091,34 +1091,34 @@ TransactionEditor* KGlobalLedgerView::startEdit(const KMyMoneyRegister::Selected
   Q_ASSERT(warnLevel < 2);  // otherwise the edit action should not be enabled
 
   switch (warnLevel) {
-  case 0:
-    break;
+    case 0:
+      break;
 
-  case 1:
-    if (KMessageBox::warningContinueCancel(0,
-                                           i18n(
-                                             "At least one split of the selected transactions has been reconciled. "
-                                             "Do you wish to continue to edit the transactions anyway?"
-                                           ),
-                                           i18n("Transaction already reconciled"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
-                                           "EditReconciledTransaction") == KMessageBox::Cancel) {
-      warnLevel = 2;
-    }
-    break;
+    case 1:
+      if (KMessageBox::warningContinueCancel(0,
+                                             i18n(
+                                               "At least one split of the selected transactions has been reconciled. "
+                                               "Do you wish to continue to edit the transactions anyway?"
+                                             ),
+                                             i18n("Transaction already reconciled"), KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                                             "EditReconciledTransaction") == KMessageBox::Cancel) {
+        warnLevel = 2;
+      }
+      break;
 
-  case 2:
-    KMessageBox::sorry(0,
-                       i18n("At least one split of the selected transactions has been frozen. "
-                            "Editing the transactions is therefore prohibited."),
-                       i18n("Transaction already frozen"));
-    break;
+    case 2:
+      KMessageBox::sorry(0,
+                         i18n("At least one split of the selected transactions has been frozen. "
+                              "Editing the transactions is therefore prohibited."),
+                         i18n("Transaction already frozen"));
+      break;
 
-  case 3:
-    KMessageBox::sorry(0,
-                       i18n("At least one split of the selected transaction references an account that has been closed. "
-                            "Editing the transactions is therefore prohibited."),
-                       i18n("Account closed"));
-    break;
+    case 3:
+      KMessageBox::sorry(0,
+                         i18n("At least one split of the selected transaction references an account that has been closed. "
+                              "Editing the transactions is therefore prohibited."),
+                         i18n("Account closed"));
+      break;
   }
 
   if (warnLevel > 1)
@@ -1244,6 +1244,13 @@ void KGlobalLedgerView::slotLeaveEditMode(const KMyMoneyRegister::SelectedTransa
     KMyMoneyRegister::Transaction* t = dynamic_cast<KMyMoneyRegister::Transaction*>(p);
     if (t)
       m_form->slotSetTransaction(t);
+  } else {
+    if (!KMyMoneySettings::transactionForm()) {
+      // update the row height of the transactions because it might differ between viewing/editing mode when not using the transaction form
+      m_register->blockSignals(true);
+      m_register->updateRegister(true);
+      m_register->blockSignals(false);
+    }
   }
 
   if (m_needReload)
@@ -1260,23 +1267,27 @@ bool KGlobalLedgerView::focusNextPrevChild(bool next)
     QWidget *w = 0;
 
     w = qApp->focusWidget();
+    // qDebug("w = %p", w);
     int currentWidgetIndex = m_tabOrderWidgets.indexOf(w);
     while (w && currentWidgetIndex == -1) {
-      // qDebug("'%s' not in list, use parent", w->className());
+      // qDebug("'%s' not in list, use parent", qPrintable(w->objectName()));
       w = w->parentWidget();
       currentWidgetIndex = m_tabOrderWidgets.indexOf(w);
     }
 
     if (currentWidgetIndex != -1) {
-      // if(w) qDebug("tab order is at '%s'", w->className());
-      QWidgetList::const_iterator it = m_tabOrderWidgets.constBegin() + currentWidgetIndex;
-      if (next)
-        w = ((it + 1) != m_tabOrderWidgets.constEnd()) ? *(it + 1) : m_tabOrderWidgets.first();
-      else
-        w = ((it - 1) != m_tabOrderWidgets.constBegin()) ? *(it - 1) : m_tabOrderWidgets.last();
+      // if(w) qDebug("tab order is at '%s'", qPrintable(w->objectName()));
+      currentWidgetIndex += next ? 1 : -1;
+      if (currentWidgetIndex < 0)
+        currentWidgetIndex = m_tabOrderWidgets.size() - 1;
+      else if (currentWidgetIndex >= m_tabOrderWidgets.size())
+        currentWidgetIndex = 0;
+
+      w = m_tabOrderWidgets[currentWidgetIndex];
+      // qDebug("currentWidgetIndex = %d, w = %p", currentWidgetIndex, w);
 
       if (((w->focusPolicy() & Qt::TabFocus) == Qt::TabFocus) && w->isVisible() && w->isEnabled()) {
-        // qDebug("Selecting '%s' as focus", w->className());
+        // qDebug("Selecting '%s' (%p) as focus", qPrintable(w->objectName()), w);
         w->setFocus();
         rc = true;
       }
@@ -1327,11 +1338,11 @@ bool KGlobalLedgerView::eventFilter(QObject* o, QEvent* e)
         if ((k->modifiers() & Qt::KeyboardModifierMask) == 0
             || (k->modifiers() & Qt::KeypadModifier) != 0) {
           switch (k->key()) {
-          case Qt::Key_Return:
-          case Qt::Key_Enter:
-            kmymoney->action("transaction_edit")->trigger();
-            rc = true;
-            break;
+            case Qt::Key_Return:
+            case Qt::Key_Enter:
+              kmymoney->action("transaction_edit")->trigger();
+              rc = true;
+              break;
           }
         }
       }
@@ -1499,6 +1510,14 @@ bool KGlobalLedgerView::canEditTransactions(const KMyMoneyRegister::SelectedTran
     }
   }
 
+  // check for multiple transactions being selected in an investment account
+  // we do not allow editing in this case: https://bugs.kde.org/show_bug.cgi?id=240816
+  // later on, we might allow to edit investment transactions of the same type
+  if (rc == true && investmentTransactions > 1) {
+    // tooltip = i18n("Cannot edit multiple investment transactions at once");
+    rc = false;
+  }
+
   // now check that we have the correct account type for investment transactions
   if (rc == true && investmentTransactions != 0) {
     if (m_account.accountType() != MyMoneyAccount::Investment) {
