@@ -234,41 +234,41 @@ void KHomeView::loadView(void)
       int option = (*it).toInt();
       if (option > 0) {
         switch (option) {
-        case 1:         // payments
-          showPayments();
-          break;
+          case 1:         // payments
+            showPayments();
+            break;
 
-        case 2:         // preferred accounts
-          showAccounts(Preferred, i18n("Preferred Accounts"));
-          break;
+          case 2:         // preferred accounts
+            showAccounts(Preferred, i18n("Preferred Accounts"));
+            break;
 
-        case 3:         // payment accounts
-          // Check if preferred accounts are shown separately
-          if (settings.contains("2")) {
-            showAccounts(static_cast<paymentTypeE>(Payment | Preferred),
-                         i18n("Payment Accounts"));
-          } else {
-            showAccounts(Payment, i18n("Payment Accounts"));
-          }
-          break;
-        case 4:         // favorite reports
-          showFavoriteReports();
-          break;
-        case 5:         // forecast
-          showForecast();
-          break;
-        case 6:         // net worth graph over all accounts
-          showNetWorthGraph();
-          break;
-        case 8:         // assets and liabilities
-          showAssetsLiabilities();
-          break;
-        case 9:         // budget
-          showBudget();
-          break;
-        case 10:         // cash flow summary
-          showCashFlowSummary();
-          break;
+          case 3:         // payment accounts
+            // Check if preferred accounts are shown separately
+            if (settings.contains("2")) {
+              showAccounts(static_cast<paymentTypeE>(Payment | Preferred),
+                           i18n("Payment Accounts"));
+            } else {
+              showAccounts(Payment, i18n("Payment Accounts"));
+            }
+            break;
+          case 4:         // favorite reports
+            showFavoriteReports();
+            break;
+          case 5:         // forecast
+            showForecast();
+            break;
+          case 6:         // net worth graph over all accounts
+            showNetWorthGraph();
+            break;
+          case 8:         // assets and liabilities
+            showAssetsLiabilities();
+            break;
+          case 9:         // budget
+            showBudget();
+            break;
+          case 10:         // cash flow summary
+            showCashFlowSummary();
+            break;
 
 
         }
@@ -421,28 +421,12 @@ void KHomeView::showPayments(void)
 
     for (it = overdues.begin(); it != overdues.end(); ++it) {
       // determine number of overdue payments
-      QDate nextDate = (*it).adjustedNextDueDate();
-      int cnt = 0;
-      while (nextDate.isValid() && nextDate < QDate::currentDate()) {
-        ++cnt;
-        nextDate = (*it).nextPayment(nextDate);
-        // for single occurrence nextDate will not change, so we
-        // better get out of here.
-        if ((*it).occurrence() == MyMoneySchedule::OCCUR_ONCE)
-          break;
-      }
+      int cnt =
+        (*it).transactionsRemainingUntil(QDate::currentDate().addDays(-1));
 
       d->m_html += QString("<tr class=\"row-%1\">").arg(i++ & 0x01 ? "even" : "odd");
       showPaymentEntry(*it, cnt);
       d->m_html += "</tr>";
-      // make sure to not repeat overdues later again
-      for (it_f = schedule.begin(); it_f != schedule.end();) {
-        if ((*it).id() == (*it_f).id()) {
-          it_f = schedule.erase(it_f);
-          continue;
-        }
-        ++it_f;
-      }
     }
     d->m_html += "</table>";
   }
@@ -458,7 +442,8 @@ void KHomeView::showPayments(void)
         todays.append(*t_it);
         (*t_it).setNextDueDate((*t_it).nextPayment((*t_it).nextDueDate()));
 
-        //if nextDueDate is still currentDate then remove it from scheduled payments
+        // if nextDueDate is still currentDate then remove it from
+        // scheduled payments
         if ((*t_it).nextDueDate() == QDate::currentDate()) {
           t_it = schedule.erase(t_it);
           continue;
@@ -549,22 +534,29 @@ void KHomeView::showPayments(void)
           needMoreLess = true;
           break;
         }
-        if (cnt > 0)
-          --cnt;
 
-        d->m_html += QString("<tr class=\"row-%1\">").arg(i++ & 0x01 ? "even" : "odd");
-        showPaymentEntry(*it);
-        d->m_html += "</tr>";
+        // in case we've shown the current recurrence as overdue,
+        // we don't show it here again, but keep the schedule
+        // as it might show up later in the list again
+        if (!(*it).isOverdue()) {
+          if (cnt > 0)
+            --cnt;
 
-        // for single occurrence we have reported everything so we
-        // better get out of here.
-        if ((*it).occurrence() == MyMoneySchedule::OCCUR_ONCE) {
-          schedule.erase(it);
-          continue;
+          d->m_html += QString("<tr class=\"row-%1\">").arg(i++ & 0x01 ? "even" : "odd");
+          showPaymentEntry(*it);
+          d->m_html += "</tr>";
+
+          // for single occurrence we have reported everything so we
+          // better get out of here.
+          if ((*it).occurrence() == MyMoneySchedule::OCCUR_ONCE) {
+            schedule.erase(it);
+            continue;
+          }
         }
 
-        //if nextPayment returns an invalid date, setNextDueDate will just skip it, resulting in a loop
-        //we check the resulting date and erase the schedule if invalid
+        // if nextPayment returns an invalid date, setNextDueDate will
+        // just skip it, resulting in a loop
+        // we check the resulting date and erase the schedule if invalid
         if (!((*it).nextPayment((*it).nextDueDate())).isValid()) {
           schedule.erase(it);
           continue;
@@ -601,8 +593,6 @@ void KHomeView::showPaymentEntry(const MyMoneySchedule& sched, int cnt)
     if (!acc.id().isEmpty()) {
       MyMoneyTransaction t = sched.transaction();
       // only show the entry, if it is still active
-      // FIXME clean old code
-      // if(!sched.isFinished() && sched.nextPayment(sched.lastPayment()) != QDate()) {
       if (!sched.isFinished()) {
         MyMoneySplit sp = t.splitByAccount(acc.id(), true);
 
@@ -673,57 +663,57 @@ void KHomeView::showAccounts(KHomeView::paymentTypeE type, const QString& header
     bool removeAccount = false;
     if (!(*it).isClosed() || showClosedAccounts) {
       switch ((*it).accountType()) {
-      case MyMoneyAccount::Expense:
-      case MyMoneyAccount::Income:
-        // never show a category account
-        // Note: This might be different in a future version when
-        //       the homepage also shows category based information
-        removeAccount = true;
-        break;
-
-        // Asset and Liability accounts are only shown if they
-        // have the preferred flag set
-      case MyMoneyAccount::Asset:
-      case MyMoneyAccount::Liability:
-      case MyMoneyAccount::Investment:
-        // if preferred accounts are requested, then keep in list
-        if ((*it).value("PreferredAccount") != "Yes"
-            || (type & Preferred) == 0) {
+        case MyMoneyAccount::Expense:
+        case MyMoneyAccount::Income:
+          // never show a category account
+          // Note: This might be different in a future version when
+          //       the homepage also shows category based information
           removeAccount = true;
-        }
-        break;
+          break;
 
-        // Check payment accounts. If payment and preferred is selected,
-        // then always show them. If only payment is selected, then
-        // show only if preferred flag is not set.
-      case MyMoneyAccount::Checkings:
-      case MyMoneyAccount::Savings:
-      case MyMoneyAccount::Cash:
-      case MyMoneyAccount::CreditCard:
-        switch (type & (Payment | Preferred)) {
-        case Payment:
-          if ((*it).value("PreferredAccount") == "Yes")
+          // Asset and Liability accounts are only shown if they
+          // have the preferred flag set
+        case MyMoneyAccount::Asset:
+        case MyMoneyAccount::Liability:
+        case MyMoneyAccount::Investment:
+          // if preferred accounts are requested, then keep in list
+          if ((*it).value("PreferredAccount") != "Yes"
+              || (type & Preferred) == 0) {
             removeAccount = true;
+          }
           break;
 
-        case Preferred:
-          if ((*it).value("PreferredAccount") != "Yes")
-            removeAccount = true;
-          break;
+          // Check payment accounts. If payment and preferred is selected,
+          // then always show them. If only payment is selected, then
+          // show only if preferred flag is not set.
+        case MyMoneyAccount::Checkings:
+        case MyMoneyAccount::Savings:
+        case MyMoneyAccount::Cash:
+        case MyMoneyAccount::CreditCard:
+          switch (type & (Payment | Preferred)) {
+            case Payment:
+              if ((*it).value("PreferredAccount") == "Yes")
+                removeAccount = true;
+              break;
 
-        case Payment | Preferred:
+            case Preferred:
+              if ((*it).value("PreferredAccount") != "Yes")
+                removeAccount = true;
+              break;
+
+            case Payment | Preferred:
+              break;
+
+            default:
+              removeAccount = true;
+              break;
+          }
           break;
 
+          // filter all accounts that are not used on homepage views
         default:
           removeAccount = true;
           break;
-        }
-        break;
-
-        // filter all accounts that are not used on homepage views
-      default:
-        removeAccount = true;
-        break;
       }
 
     } else if ((*it).isClosed() || (*it).isInvest()) {
@@ -791,6 +781,9 @@ void KHomeView::showAccountEntry(const MyMoneyAccount& acc)
     if (acc.accountType() == MyMoneyAccount::CreditCard ||
         acc.accountType() == MyMoneyAccount::Checkings) {
       QString maximumCredit = acc.value("maxCreditAbsolute");
+      if (maximumCredit.isEmpty()) {
+        maximumCredit = acc.value("minBalanceAbsolute");
+      }
       MyMoneyMoney maxCredit = MyMoneyMoney(maximumCredit);
       showAccountEntry(acc, value, value - maxCredit, showLimit);
     } else {
@@ -1002,18 +995,18 @@ void KHomeView::showForecast(void)
           && (dropMinimum < dropZero
               || dropZero == -1)) {
         switch (dropMinimum) {
-        case -1:
-          break;
-        case 0:
-          msg = i18n("The balance of %1 is below the minimum balance %2 today.", (*it_account).name(), minBalance.formatMoney(*it_account, currency));
-          msg = showColoredAmount(msg, true);
-          break;
-        default:
-          msg = i18np("The balance of %2 will drop below the minimum balance %3 in %1 day.",
-                      "The balance of %2 will drop below the minimum balance %3 in %1 days.",
-                      dropMinimum - 1, (*it_account).name(), minBalance.formatMoney(*it_account, currency));
-          msg = showColoredAmount(msg, true);
-          break;
+          case -1:
+            break;
+          case 0:
+            msg = i18n("The balance of %1 is below the minimum balance %2 today.", (*it_account).name(), minBalance.formatMoney(*it_account, currency));
+            msg = showColoredAmount(msg, true);
+            break;
+          default:
+            msg = i18np("The balance of %2 will drop below the minimum balance %3 in %1 day.",
+                        "The balance of %2 will drop below the minimum balance %3 in %1 days.",
+                        dropMinimum - 1, (*it_account).name(), minBalance.formatMoney(*it_account, currency));
+            msg = showColoredAmount(msg, true);
+            break;
         }
 
         if (!msg.isEmpty()) {
@@ -1023,33 +1016,33 @@ void KHomeView::showForecast(void)
       // a drop below zero is always shown
       msg.clear();
       switch (dropZero) {
-      case -1:
-        break;
-      case 0:
-        if ((*it_account).accountGroup() == MyMoneyAccount::Asset) {
-          msg = i18n("The balance of %1 is below %2 today.", (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
-          msg = showColoredAmount(msg, true);
+        case -1:
           break;
-        }
-        if ((*it_account).accountGroup() == MyMoneyAccount::Liability) {
-          msg = i18n("The balance of %1 is above %2 today.", (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
+        case 0:
+          if ((*it_account).accountGroup() == MyMoneyAccount::Asset) {
+            msg = i18n("The balance of %1 is below %2 today.", (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
+            msg = showColoredAmount(msg, true);
+            break;
+          }
+          if ((*it_account).accountGroup() == MyMoneyAccount::Liability) {
+            msg = i18n("The balance of %1 is above %2 today.", (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
+            break;
+          }
           break;
-        }
-        break;
-      default:
-        if ((*it_account).accountGroup() == MyMoneyAccount::Asset) {
-          msg = i18np("The balance of %2 will drop below %3 in %1 day.",
-                      "The balance of %2 will drop below %3 in %1 days.",
-                      dropZero, (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
-          msg = showColoredAmount(msg, true);
-          break;
-        }
-        if ((*it_account).accountGroup() == MyMoneyAccount::Liability) {
-          msg = i18np("The balance of %2 will raise above %3 in %1 day.",
-                      "The balance of %2 will raise above %3 in %1 days.",
-                      dropZero, (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
-          break;
-        }
+        default:
+          if ((*it_account).accountGroup() == MyMoneyAccount::Asset) {
+            msg = i18np("The balance of %2 will drop below %3 in %1 day.",
+                        "The balance of %2 will drop below %3 in %1 days.",
+                        dropZero, (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
+            msg = showColoredAmount(msg, true);
+            break;
+          }
+          if ((*it_account).accountGroup() == MyMoneyAccount::Liability) {
+            msg = i18np("The balance of %2 will raise above %3 in %1 day.",
+                        "The balance of %2 will raise above %3 in %1 days.",
+                        dropZero, (*it_account).name(), MyMoneyMoney().formatMoney(*it_account, currency));
+            break;
+          }
       }
       if (!msg.isEmpty()) {
         d->m_html += QString("<tr class=\"warning\"><td colspan=%2 align=\"center\" ><b>%1</b></td></tr>").arg(msg).arg(colspan);
@@ -1087,24 +1080,20 @@ void KHomeView::slotOpenUrl(const KUrl &url, const KParts::OpenUrlArguments&, co
   } else if (protocol == "mailto") {
     KToolInvocation::invokeMailer(url);
   } else {
+    KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
+    Q_CHECK_PTR(mw);
     if (view == VIEW_LEDGER) {
       emit ledgerSelected(id, QString());
 
     } else if (view == VIEW_SCHEDULE) {
       if (mode == "enter") {
         emit scheduleSelected(id);
-        KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
-        Q_CHECK_PTR(mw);
         QTimer::singleShot(0, mw->actionCollection()->action("schedule_enter"), SLOT(trigger()));
       } else if (mode == "edit") {
         emit scheduleSelected(id);
-        KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
-        Q_CHECK_PTR(mw);
         QTimer::singleShot(0, mw->actionCollection()->action("schedule_edit"), SLOT(trigger()));
       } else if (mode == "skip") {
         emit scheduleSelected(id);
-        KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
-        Q_CHECK_PTR(mw);
         QTimer::singleShot(0, mw->actionCollection()->action("schedule_skip"), SLOT(trigger()));
       } else if (mode == "full") {
         d->m_showAllSchedules = true;
@@ -1119,8 +1108,6 @@ void KHomeView::slotOpenUrl(const KUrl &url, const KParts::OpenUrlArguments&, co
       emit reportSelected(id);
 
     } else if (view == VIEW_WELCOME) {
-      KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
-      Q_CHECK_PTR(mw);
       if (mode == "whatsnew") {
         d->m_part->begin();
         d->m_part->write(KWelcomePage::whatsNewPage());
@@ -1132,8 +1119,6 @@ void KHomeView::slotOpenUrl(const KUrl &url, const KParts::OpenUrlArguments&, co
       }
 
     } else if (view == "action") {
-      KXmlGuiWindow* mw = KMyMoneyUtils::mainWindow();
-      Q_CHECK_PTR(mw);
       QTimer::singleShot(0, mw->actionCollection()->action(id), SLOT(trigger()));
     } else if (view == VIEW_HOME) {
       QList<MyMoneyAccount> list;
@@ -1169,34 +1154,34 @@ void KHomeView::showAssetsLiabilities(void)
   for (it = accounts.begin(); it != accounts.end();) {
     if (!(*it).isClosed()) {
       switch ((*it).accountType()) {
-        // group all assets into one list but make sure that investment accounts always show up
-      case MyMoneyAccount::Investment:
-        d->addNameIndex(nameAssetsIdx, *it);
-        break;
-
-      case MyMoneyAccount::Checkings:
-      case MyMoneyAccount::Savings:
-      case MyMoneyAccount::Cash:
-      case MyMoneyAccount::Asset:
-      case MyMoneyAccount::AssetLoan:
-        // list account if it's the last in the hierarchy or has transactions in it
-        if ((*it).accountList().isEmpty() || (file->transactionCount((*it).id()) > 0)) {
+          // group all assets into one list but make sure that investment accounts always show up
+        case MyMoneyAccount::Investment:
           d->addNameIndex(nameAssetsIdx, *it);
-        }
-        break;
+          break;
 
-        // group the liabilities into the other
-      case MyMoneyAccount::CreditCard:
-      case MyMoneyAccount::Liability:
-      case MyMoneyAccount::Loan:
-        // list account if it's the last in the hierarchy or has transactions in it
-        if ((*it).accountList().isEmpty() || (file->transactionCount((*it).id()) > 0)) {
-          d->addNameIndex(nameLiabilitiesIdx, *it);
-        }
-        break;
+        case MyMoneyAccount::Checkings:
+        case MyMoneyAccount::Savings:
+        case MyMoneyAccount::Cash:
+        case MyMoneyAccount::Asset:
+        case MyMoneyAccount::AssetLoan:
+          // list account if it's the last in the hierarchy or has transactions in it
+          if ((*it).accountList().isEmpty() || (file->transactionCount((*it).id()) > 0)) {
+            d->addNameIndex(nameAssetsIdx, *it);
+          }
+          break;
 
-      default:
-        break;
+          // group the liabilities into the other
+        case MyMoneyAccount::CreditCard:
+        case MyMoneyAccount::Liability:
+        case MyMoneyAccount::Loan:
+          // list account if it's the last in the hierarchy or has transactions in it
+          if ((*it).accountList().isEmpty() || (file->transactionCount((*it).id()) > 0)) {
+            d->addNameIndex(nameLiabilitiesIdx, *it);
+          }
+          break;
+
+        default:
+          break;
       }
     }
     ++it;
@@ -1474,7 +1459,7 @@ void KHomeView::doForecast(void)
   d->m_accountList.clear();
 
   //reinitialize the object
-  d->m_forecast = MyMoneyForecast();
+  d->m_forecast = KMyMoneyGlobalSettings::forecast();
 
   //If forecastDays lower than accountsCycle, adjust to the first cycle
   if (d->m_forecast.accountsCycle() > d->m_forecast.forecastDays())
@@ -1695,41 +1680,41 @@ void KHomeView::showCashFlowSummary()
   for (account_it = accounts.constBegin(); account_it != accounts.constEnd();) {
     if (!(*account_it).isClosed()) {
       switch ((*account_it).accountType()) {
-        //group all assets into one list
-      case MyMoneyAccount::Checkings:
-      case MyMoneyAccount::Savings:
-      case MyMoneyAccount::Cash: {
-        MyMoneyMoney value = MyMoneyFile::instance()->balance((*account_it).id(), QDate::currentDate());
-        //calculate balance for foreign currency accounts
-        if ((*account_it).currencyId() != file->baseCurrency().id()) {
-          ReportAccount repAcc = ReportAccount((*account_it).id());
-          MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(QDate::currentDate());
-          MyMoneyMoney baseValue = value * curPrice;
-          liquidAssets += baseValue;
-          liquidAssets = liquidAssets.convert(10000);
-        } else {
-          liquidAssets += value;
-        }
-        break;
-      }
-      //group the liabilities into the other
-      case MyMoneyAccount::CreditCard: {
-        MyMoneyMoney value;
-        value = MyMoneyFile::instance()->balance((*account_it).id(), QDate::currentDate());
-        //calculate balance if foreign currency
-        if ((*account_it).currencyId() != file->baseCurrency().id()) {
-          ReportAccount repAcc = ReportAccount((*account_it).id());
-          MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(QDate::currentDate());
-          MyMoneyMoney baseValue = value * curPrice;
-          liquidLiabilities += baseValue;
-          liquidLiabilities = liquidLiabilities.convert(10000);
-        } else {
-          liquidLiabilities += value;
-        }
-        break;
-      }
-      default:
-        break;
+          //group all assets into one list
+        case MyMoneyAccount::Checkings:
+        case MyMoneyAccount::Savings:
+        case MyMoneyAccount::Cash: {
+            MyMoneyMoney value = MyMoneyFile::instance()->balance((*account_it).id(), QDate::currentDate());
+            //calculate balance for foreign currency accounts
+            if ((*account_it).currencyId() != file->baseCurrency().id()) {
+              ReportAccount repAcc = ReportAccount((*account_it).id());
+              MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(QDate::currentDate());
+              MyMoneyMoney baseValue = value * curPrice;
+              liquidAssets += baseValue;
+              liquidAssets = liquidAssets.convert(10000);
+            } else {
+              liquidAssets += value;
+            }
+            break;
+          }
+          //group the liabilities into the other
+        case MyMoneyAccount::CreditCard: {
+            MyMoneyMoney value;
+            value = MyMoneyFile::instance()->balance((*account_it).id(), QDate::currentDate());
+            //calculate balance if foreign currency
+            if ((*account_it).currencyId() != file->baseCurrency().id()) {
+              ReportAccount repAcc = ReportAccount((*account_it).id());
+              MyMoneyMoney curPrice = repAcc.baseCurrencyPrice(QDate::currentDate());
+              MyMoneyMoney baseValue = value * curPrice;
+              liquidLiabilities += baseValue;
+              liquidLiabilities = liquidLiabilities.convert(10000);
+            } else {
+              liquidLiabilities += value;
+            }
+            break;
+          }
+        default:
+          break;
       }
     }
     ++account_it;
