@@ -58,21 +58,12 @@
 // ----------------------------------------------------------------------------
 // Project Includes
 
-// This is include is required here, because later it will produce
-// compile errors on gcc 3.2 as we redefine new() in case of _CHECK_MEMORY
-// being defined. To avoid these problems, we just include the header
-// already here in this case
-#ifdef _CHECK_MEMORY
-#include <string>
-#endif
-
 #include <config-kmymoney.h>
 #include <kmymoneyglobalsettings.h>
 #include <kmymoneytitlelabel.h>
 #include <libkgpgfile/kgpgfile.h>
 #include "kendingbalancedlg.h"
 #include "kchooseimportexportdlg.h"
-#include "kcsvprogressdlg.h"
 #include "kimportdlg.h"
 #include "kexportdlg.h"
 #include "knewloanwizard.h"
@@ -111,10 +102,10 @@
 
 KMyMoneyView::KMyMoneyView(QWidget *parent)
     : KPageWidget(parent),
-    // m_bankRightClick(false),
     m_inConstructor(true),
     m_fileOpen(false),
-    m_fmode(0600)
+    m_fmode(0600),
+    m_lastViewSelected(0)
 {
   // the global variable kmymoney is not yet assigned. So we construct it here
   QObject* kmymoney = parent->parent();
@@ -152,13 +143,11 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
   connect(m_institutionsView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowInstitutionContextMenu(const MyMoneyObject&)));
   connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotInstitutionEdit(const MyMoneyObject&)));
   connect(m_institutionsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_institutionsView, SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyInstitution&)), kmymoney, SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyInstitution&)));
-  connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_institutionsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
 
   // Page 2
   m_accountsView = new KAccountsView();
   m_accountsViewFrame = m_model->addPage(m_accountsView, i18n("Accounts"));
-  m_accountsViewFrame->setIcon(KIcon("account"));
+  m_accountsViewFrame->setIcon(KIcon("account")); //krazy:exclude=iconnames
   m_accountsViewFrame->setHeader(QString(""));
   addTitleBar(m_accountsView, i18n("Accounts"));
 
@@ -167,8 +156,6 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
   connect(m_accountsView, SIGNAL(selectObject(const MyMoneyObject&)), kmymoney, SLOT(slotSelectInvestment(const MyMoneyObject&)));
   connect(m_accountsView, SIGNAL(openContextMenu(const MyMoneyObject&)), kmymoney, SLOT(slotShowAccountContextMenu(const MyMoneyObject&)));
   connect(m_accountsView, SIGNAL(openObject(const MyMoneyObject&)), kmymoney, SLOT(slotAccountOpen(const MyMoneyObject&)));
-  connect(m_accountsView, SIGNAL(reparent(const MyMoneyAccount&, const MyMoneyAccount&)), kmymoney, SLOT(slotReparentAccount(const MyMoneyAccount&, const MyMoneyAccount&)));
-  //connect(this, SIGNAL(kmmFilePlugin(unsigned int)), m_accountsView, SLOT(slotUpdateIconPos(unsigned int)));
   connect(this, SIGNAL(reconciliationStarts(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)), m_accountsView, SLOT(slotReconcileAccount(const MyMoneyAccount&, const QDate&, const MyMoneyMoney&)));
 
   // Page 3
@@ -216,7 +203,7 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
   // Page 6
   m_ledgerView = new KGlobalLedgerView();
   m_ledgerViewFrame = m_model->addPage(m_ledgerView, i18n("Ledgers"));
-  m_ledgerViewFrame->setIcon(KIcon("ledger"));
+  m_ledgerViewFrame->setIcon(KIcon("ledger"));  //krazy:exclude=iconnames
   m_ledgerViewFrame->setHeader(QString(""));
   connect(m_ledgerView, SIGNAL(accountSelected(const MyMoneyObject&)), kmymoney, SLOT(slotSelectAccount(const MyMoneyObject&)));
   connect(m_ledgerView, SIGNAL(openContextMenu()), kmymoney, SLOT(slotShowTransactionContextMenu()));
@@ -278,6 +265,7 @@ KMyMoneyView::KMyMoneyView(QWidget *parent)
 
 KMyMoneyView::~KMyMoneyView()
 {
+  KMyMoneyGlobalSettings::setLastViewSelected(m_lastViewSelected);
   removeStorage();
 }
 
@@ -307,22 +295,21 @@ void KMyMoneyView::updateViewType(void)
   // set the face type
   KPageView::FaceType faceType = KPageView::List;
   switch (KMyMoneySettings::viewType()) {
-  case 0:
-    faceType = KPageView::List;
-    break;
-  case 1:
-    faceType = KPageView::Tree;
-    break;
-  case 2:
-    faceType = KPageView::Tabbed;
-    break;
+    case 0:
+      faceType = KPageView::List;
+      break;
+    case 1:
+      faceType = KPageView::Tree;
+      break;
+    case 2:
+      faceType = KPageView::Tabbed;
+      break;
   }
   setFaceType(faceType);
 }
 
 void KMyMoneyView::showPage(KPageWidgetItem* pageItem)
 {
-
   // reset all selected items before showing the selected view
   // but not while we're in our own constructor
   if (!m_inConstructor && pageItem != currentPage()) {
@@ -351,7 +338,6 @@ void KMyMoneyView::showPage(KPageWidgetItem* pageItem)
 
 bool KMyMoneyView::canPrint(void)
 {
-
   bool rc = (
               m_reportsViewFrame == currentPage()
               || m_homeViewFrame == currentPage()
@@ -491,38 +477,38 @@ void KMyMoneyView::slotLedgerSelected(const QString& _accId, const QString& tran
   QString accId(_accId);
 
   switch (acc.accountType()) {
-  case MyMoneyAccount::Stock:
-    // if a stock account is selected, we show the
-    // the corresponding parent (investment) account
-    acc = MyMoneyFile::instance()->account(acc.parentAccountId());
-    accId = acc.id();
-    // tricky fall through here
+    case MyMoneyAccount::Stock:
+      // if a stock account is selected, we show the
+      // the corresponding parent (investment) account
+      acc = MyMoneyFile::instance()->account(acc.parentAccountId());
+      accId = acc.id();
+      // tricky fall through here
 
-  case MyMoneyAccount::Checkings:
-  case MyMoneyAccount::Savings:
-  case MyMoneyAccount::Cash:
-  case MyMoneyAccount::CreditCard:
-  case MyMoneyAccount::Loan:
-  case MyMoneyAccount::Asset:
-  case MyMoneyAccount::Liability:
-  case MyMoneyAccount::AssetLoan:
-  case MyMoneyAccount::Income:
-  case MyMoneyAccount::Expense:
-  case MyMoneyAccount::Investment:
-  case MyMoneyAccount::Equity:
-    setCurrentPage(m_ledgerViewFrame);
-    m_ledgerView->slotSelectAccount(accId, transaction);
-    break;
+    case MyMoneyAccount::Checkings:
+    case MyMoneyAccount::Savings:
+    case MyMoneyAccount::Cash:
+    case MyMoneyAccount::CreditCard:
+    case MyMoneyAccount::Loan:
+    case MyMoneyAccount::Asset:
+    case MyMoneyAccount::Liability:
+    case MyMoneyAccount::AssetLoan:
+    case MyMoneyAccount::Income:
+    case MyMoneyAccount::Expense:
+    case MyMoneyAccount::Investment:
+    case MyMoneyAccount::Equity:
+      setCurrentPage(m_ledgerViewFrame);
+      m_ledgerView->slotSelectAccount(accId, transaction);
+      break;
 
-  case MyMoneyAccount::CertificateDep:
-  case MyMoneyAccount::MoneyMarket:
-  case MyMoneyAccount::Currency:
-    qDebug("No ledger view available for account type %d", acc.accountType());
-    break;
+    case MyMoneyAccount::CertificateDep:
+    case MyMoneyAccount::MoneyMarket:
+    case MyMoneyAccount::Currency:
+      qDebug("No ledger view available for account type %d", acc.accountType());
+      break;
 
-  default:
-    qDebug("Unknown account type %d in KMyMoneyView::slotLedgerSelected", acc.accountType());
-    break;
+    default:
+      qDebug("Unknown account type %d in KMyMoneyView::slotLedgerSelected", acc.accountType());
+      break;
   }
 }
 
@@ -592,7 +578,7 @@ bool KMyMoneyView::readFile(const KUrl& url)
   m_fileOpen = false;
   bool isEncrypted = false;
 
-  IMyMoneyStorageFormat* pReader = NULL;
+  IMyMoneyStorageFormat* pReader = 0;
 
   if (!url.isValid()) {
     qDebug("Invalid URL '%s'", qPrintable(url.url()));
@@ -616,7 +602,7 @@ bool KMyMoneyView::readFile(const KUrl& url)
   if (url.isLocalFile()) {
     filename = url.toLocalFile();
   } else {
-    if (!KIO::NetAccess::download(url, filename, NULL)) {
+    if (!KIO::NetAccess::download(url, filename, 0)) {
       KMessageBox::detailedError(this,
                                  i18n("Error while loading file '%1'.", url.url()),
                                  KIO::NetAccess::lastErrorString(),
@@ -844,29 +830,29 @@ bool KMyMoneyView::openDatabase(const KUrl& url)
   bool retry = true;
   while (retry) {
     switch (reader->open(dbURL, QIODevice::ReadWrite)) {
-    case 0: // opened okay
-      retry = false;
-      break;
-    case 1: // permanent error
-      KMessageBox::detailedError(this, i18n("Cannot open database %1\n", dbURL.prettyUrl()), reader->lastError());
-      if (pDBMgr) {
-        removeStorage();
-        delete pDBMgr;
-      }
-      return false;
-    case -1: // retryable error
-      if (KMessageBox::warningYesNo(this, reader->lastError(), PACKAGE) == KMessageBox::No) {
+      case 0: // opened okay
+        retry = false;
+        break;
+      case 1: // permanent error
+        KMessageBox::detailedError(this, i18n("Cannot open database %1\n", dbURL.prettyUrl()), reader->lastError());
         if (pDBMgr) {
           removeStorage();
           delete pDBMgr;
         }
         return false;
-      } else {
-        QString options = dbURL.queryItem("options") + ",override";
-        dbURL.removeQueryItem("mode"); // now redundant
-        dbURL.removeQueryItem("options");
-        dbURL.addQueryItem("options", options);
-      }
+      case -1: // retryable error
+        if (KMessageBox::warningYesNo(this, reader->lastError(), PACKAGE) == KMessageBox::No) {
+          if (pDBMgr) {
+            removeStorage();
+            delete pDBMgr;
+          }
+          return false;
+        } else {
+          QString options = dbURL.queryItem("options") + ",override";
+          dbURL.removeQueryItem("mode"); // now redundant
+          dbURL.removeQueryItem("options");
+          dbURL.addQueryItem("options", options);
+        }
     }
   }
   if (pDBMgr) {
@@ -934,14 +920,11 @@ bool KMyMoneyView::initializeStorage()
   }
 
   KSharedConfigPtr config = KGlobal::config();
-  int pageIndex = 0;
   KPageWidgetItem* page;
   KConfigGroup grp = config->group("General Options");
 
   if (KMyMoneyGlobalSettings::startLastViewSelected() != 0) {
-    KConfigGroup _grp2 = config->group("Last Use Settings");
-    pageIndex = _grp2.readEntry("LastViewSelected", 0);
-    page = m_model->item(m_model->index(pageIndex, 0));
+    page = m_model->item(m_model->index(KMyMoneyGlobalSettings::lastViewSelected(), 0));
   } else {
     page = m_homeViewFrame;
   }
@@ -958,25 +941,25 @@ bool KMyMoneyView::initializeStorage()
       while (s->fileFixVersion() < s->currentFixVersion()) {
         qDebug("%s", qPrintable((QString("testing fileFixVersion %1 < %2").arg(s->fileFixVersion()).arg(s->currentFixVersion()))));
         switch (s->fileFixVersion()) {
-        case 0:
-          fixFile_0();
-          s->setFileFixVersion(1);
-          break;
+          case 0:
+            fixFile_0();
+            s->setFileFixVersion(1);
+            break;
 
-        case 1:
-          fixFile_1();
-          s->setFileFixVersion(2);
-          break;
+          case 1:
+            fixFile_1();
+            s->setFileFixVersion(2);
+            break;
 
-        case 2:
-          fixFile_2();
-          s->setFileFixVersion(3);
-          break;
+          case 2:
+            fixFile_2();
+            s->setFileFixVersion(3);
+            break;
 
-          // add new levels above. Don't forget to increase currentFixVersion() for all
-          // the storage backends this fix applies to
-        default:
-          throw new MYMONEYEXCEPTION(i18n("Unknown fix level in input file"));
+            // add new levels above. Don't forget to increase currentFixVersion() for all
+            // the storage backends this fix applies to
+          default:
+            throw new MYMONEYEXCEPTION(i18n("Unknown fix level in input file"));
         }
       }
       ft.commit();
@@ -1007,7 +990,7 @@ bool KMyMoneyView::initializeStorage()
   MyMoneyFile::instance()->forceDataChanged();
 
   // if we currently see a different page, then select the right one
-  if (pageIndex != KPageView::currentPage().row()) {
+  if (m_model->index(page).row() != KPageView::currentPage().row()) {
     showPage(page);
   }
 
@@ -1032,7 +1015,7 @@ void KMyMoneyView::saveToLocalFile(const QString& localFile, IMyMoneyStorageForm
     if (KMyMoneyGlobalSettings::encryptRecover()) {
       encryptRecover = true;
       if (!KGPGFile::keyAvailable(QString(RECOVER_KEY_ID))) {
-        KMessageBox::sorry(this, i18n("<p>You have selected to encrypt your data also with the KMyMoney recover key, but the key with id</p><p><center><b>%1</b></center></p><p>has not been found in your keyring at this time. Please make sure to import this key into your keyring. You can find it on the <a href=\"http://kmymoney2.sourceforge.net/\">KMyMoney web-site</a>. This time your data will not be encrypted with the KMyMoney recover key.</p>", QString(RECOVER_KEY_ID)), i18n("GPG-Key not found"));
+        KMessageBox::sorry(this, i18n("<p>You have selected to encrypt your data also with the KMyMoney recover key, but the key with id</p><p><center><b>%1</b></center></p><p>has not been found in your keyring at this time. Please make sure to import this key into your keyring. You can find it on the <a href=\"http://kmymoney.org/\">KMyMoney web-site</a>. This time your data will not be encrypted with the KMyMoney recover key.</p>", QString(RECOVER_KEY_ID)), i18n("GPG-Key not found"));
         encryptRecover = false;
       }
     }
@@ -1047,7 +1030,7 @@ void KMyMoneyView::saveToLocalFile(const QString& localFile, IMyMoneyStorageForm
     }
 
     if (encryptedOk == true) {
-      QString msg = i18n("<p>You have configured to save your data in encrypted form using GPG. Please be aware, that this is a brand new feature which is yet untested. Make sure, you have the necessary understanding that you might loose all your data if you store it encrypted and cannot decrypt it later on. If unsure, answer <b>No</b>.</p>");
+      QString msg = i18n("<p>You have configured to save your data in encrypted form using GPG. Make sure you understand that you might lose all your data if you encrypt it, but cannot decrypt it later on. If unsure, answer <b>No</b>.</p>");
 
       if (KMessageBox::questionYesNo(this, msg, i18n("Store GPG encrypted"), KStandardGuiItem::yes(), KStandardGuiItem::no(), "StoreEncrypted") == KMessageBox::No) {
         encryptedOk = false;
@@ -1136,7 +1119,7 @@ bool KMyMoneyView::saveFile(const KUrl& url, const QString& keyList)
   }
 
   emit kmmFilePlugin(preSave);
-  IMyMoneyStorageFormat* pWriter = NULL;
+  IMyMoneyStorageFormat* pWriter = 0;
 
   // If this file ends in ".ANON.XML" then this should be written using the
   // anonymous writer.
@@ -1188,7 +1171,7 @@ bool KMyMoneyView::saveFile(const KUrl& url, const QString& keyList)
       KTemporaryFile tmpfile;
       tmpfile.open(); // to obtain the name
       saveToLocalFile(tmpfile.fileName(), pWriter, plaintext, keyList);
-      if (!KIO::NetAccess::upload(tmpfile.fileName(), url, NULL))
+      if (!KIO::NetAccess::upload(tmpfile.fileName(), url, 0))
         throw new MYMONEYEXCEPTION(i18n("Unable to upload to '%1'", url.url()));
       tmpfile.close();
     }
@@ -1214,19 +1197,19 @@ bool KMyMoneyView::saveAsDatabase(const KUrl& url)
   MyMoneyStorageSql *writer = new MyMoneyStorageSql(dynamic_cast<IMyMoneySerialize*>(MyMoneyFile::instance()->storage()), url);
   bool canWrite = false;
   switch (writer->open(url, QIODevice::WriteOnly)) {
-  case 0:
-    canWrite = true;
-    break;
-  case -1: // dbase already has data, see if he wants to clear it out
-    if (KMessageBox::warningContinueCancel(0,
-                                           i18n("Database contains data which must be removed before using Save As.\n"
-                                                "Do you wish to continue?"), "Database not empty") == KMessageBox::Continue) {
-      if (writer->open(url, QIODevice::WriteOnly, true) == 0) canWrite = true;
-    } else {
-      delete writer;
-      return false;
-    }
-    break;
+    case 0:
+      canWrite = true;
+      break;
+    case -1: // dbase already has data, see if he wants to clear it out
+      if (KMessageBox::warningContinueCancel(0,
+                                             i18n("Database contains data which must be removed before using Save As.\n"
+                                                  "Do you wish to continue?"), "Database not empty") == KMessageBox::Continue) {
+        if (writer->open(url, QIODevice::WriteOnly, true) == 0) canWrite = true;
+      } else {
+        delete writer;
+        return false;
+      }
+      break;
   }
   if (canWrite) {
     writer->setProgressCallback(&KMyMoneyView::progressCallback);
@@ -1664,13 +1647,7 @@ void KMyMoneyView::progressCallback(int current, int total, const QString& msg)
 
 void KMyMoneyView::slotRememberPage(const QModelIndex current, const QModelIndex)
 {
-  // only remember a changed setting if we're not called during construction
-  if (!m_inConstructor) {
-    KSharedConfigPtr config = KGlobal::config();
-    KConfigGroup grp = config->group("Last Use Settings");
-    grp.writeEntry("LastViewSelected", current.row());
-    config->sync();
-  }
+  m_lastViewSelected = current.row();
 }
 
 /* DO NOT ADD code to this function or any of it's called ones.
@@ -1919,7 +1896,7 @@ void KMyMoneyView::fixLoanAccount_0(MyMoneyAccount acc)
       || acc.value("schedule").isEmpty()
       || acc.value("fixed-interest").isEmpty()) {
     KMessageBox::information(this,
-                             i18n("<p>The account \"%1\" was previously created as loan account but some information is missing.</p><p>The new loan wizard will be started to collect all relevant information.</p><p>Please use a KMyMoney version >= 0.8.7 and < 0.9 to correct the problem.</p>"
+                             i18n("<p>The account \"%1\" was previously created as loan account but some information is missing.</p><p>The new loan wizard will be started to collect all relevant information.</p><p>Please use KMyMoney version 0.8.7 or later and earlier than version 0.9 to correct the problem.</p>"
                                   , acc.name()),
                              i18n("Account problem"));
 
@@ -2118,14 +2095,11 @@ void KMyMoneyView::fixTransactions_0(void)
     }
 #endif
 
-    bool hasDuplicateAccounts = false;
     // Check for correct assignment of ActionInterest in all splits
     // and check if there are any duplicates in this transactions
     for (it_s = splits.begin(); it_s != splits.end(); ++it_s) {
       MyMoneyAccount splitAccount = file->account((*it_s).accountId());
-      if (accounts.contains((*it_s).accountId())) {
-        hasDuplicateAccounts = true;
-      } else {
+      if (!accounts.contains((*it_s).accountId())) {
         accounts << (*it_s).accountId();
       }
       // if this split references an interest account, the action
@@ -2179,13 +2153,6 @@ void KMyMoneyView::fixTransactions_0(void)
       }
     }
 
-    /*
-        // if there are at least two splits referencing the same account,
-        // we need to combine them into one and get rid of the others
-        if(hasDuplicateAccounts) {
-          fixDuplicateAccounts(*it_t);
-        }
-    */
     ++cnt;
     if (!(cnt % 10))
       kmymoney->slotStatusProgressBar(cnt);
