@@ -590,8 +590,13 @@ const MyMoneySecurity& AccountTypePage::currency(void) const
 
 void AccountTypePage::setAccount(const MyMoneyAccount& acc)
 {
-  if (acc.accountType() != MyMoneyAccount::UnknownAccountType)
-    m_typeSelection->setCurrentItem(acc.accountType());
+  if (acc.accountType() != MyMoneyAccount::UnknownAccountType) {
+    if (acc.accountType() == MyMoneyAccount::AssetLoan) {
+      m_typeSelection->setCurrentItem(MyMoneyAccount::Loan);
+    } else {
+      m_typeSelection->setCurrentItem(acc.accountType());
+    }
+  }
   m_openingDate->setDate(acc.openingDate());
   m_accountName->setText(acc.name());
 }
@@ -599,15 +604,15 @@ void AccountTypePage::setAccount(const MyMoneyAccount& acc)
 const MyMoneyAccount& AccountTypePage::parentAccount(void)
 {
   switch (accountType()) {
-  case MyMoneyAccount::CreditCard:
-  case MyMoneyAccount::Liability:
-  case MyMoneyAccount::Loan: // Can be either but we return liability here
-    return MyMoneyFile::instance()->liability();
-    break;
-  case MyMoneyAccount::Equity:
-    return MyMoneyFile::instance()->equity();
-  default:
-    break;
+    case MyMoneyAccount::CreditCard:
+    case MyMoneyAccount::Liability:
+    case MyMoneyAccount::Loan: // Can be either but we return liability here
+      return MyMoneyFile::instance()->liability();
+      break;
+    case MyMoneyAccount::Equity:
+      return MyMoneyFile::instance()->equity();
+    default:
+      break;
   }
   return MyMoneyFile::instance()->asset();
 }
@@ -868,19 +873,19 @@ void LoanDetailsPage::enterPage(void)
   }
 
   switch (m_wizard->m_generalLoanInfoPage->m_paymentFrequency->currentItem()) {
-  default:
-    m_termUnit->insertItem(i18n("Payments"), MyMoneySchedule::OCCUR_ONCE);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_ONCE);
-    break;
-  case MyMoneySchedule::OCCUR_MONTHLY:
-    m_termUnit->insertItem(i18n("Months"), MyMoneySchedule::OCCUR_MONTHLY);
-    m_termUnit->insertItem(i18n("Years"), MyMoneySchedule::OCCUR_YEARLY);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_MONTHLY);
-    break;
-  case MyMoneySchedule::OCCUR_YEARLY:
-    m_termUnit->insertItem(i18n("Years"), MyMoneySchedule::OCCUR_YEARLY);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_YEARLY);
-    break;
+    default:
+      m_termUnit->insertItem(i18n("Payments"), MyMoneySchedule::OCCUR_ONCE);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_ONCE);
+      break;
+    case MyMoneySchedule::OCCUR_MONTHLY:
+      m_termUnit->insertItem(i18n("Months"), MyMoneySchedule::OCCUR_MONTHLY);
+      m_termUnit->insertItem(i18n("Years"), MyMoneySchedule::OCCUR_YEARLY);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_MONTHLY);
+      break;
+    case MyMoneySchedule::OCCUR_YEARLY:
+      m_termUnit->insertItem(i18n("Years"), MyMoneySchedule::OCCUR_YEARLY);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_YEARLY);
+      break;
   }
 }
 
@@ -955,6 +960,12 @@ void LoanDetailsPage::slotCalculate(void)
     } else if (m_interestRate->lineedit()->text().isEmpty()) {
       // calculate the interest rate out of the other information
       val = calc.interestRate();
+
+      //FIXME: Allow 0% interest rates when the remaining issues are fixed
+      //BUGS 246103 and 246105 on BKO
+      if (val == 0)
+        throw new MYMONEYEXCEPTION("incorrect fincancial calculation");
+
       m_interestRate->loadText(MyMoneyMoney(static_cast<double>(val)).abs().formatMoney("", 3));
       result = i18n("KMyMoney has calculated the interest rate to %1%.", m_interestRate->lineedit()->text());
 
@@ -1071,25 +1082,25 @@ int LoanDetailsPage::term(void) const
   if (m_termAmount->value() != 0) {
     factor = 1;
     switch (m_termUnit->currentItem()) {
-    case MyMoneySchedule::OCCUR_YEARLY: // years
-      factor = 12;
-      // tricky fall through here
+      case MyMoneySchedule::OCCUR_YEARLY: // years
+        factor = 12;
+        // tricky fall through here
 
-    case MyMoneySchedule::OCCUR_MONTHLY: // months
-      factor *= 30;
-      factor *= m_termAmount->value();
-      // factor now is the duration in days. we divide this by the
-      // payment frequency and get the number of payments
-      factor /= m_wizard->m_generalLoanInfoPage->m_paymentFrequency->daysBetweenEvents();
-      break;
+      case MyMoneySchedule::OCCUR_MONTHLY: // months
+        factor *= 30;
+        factor *= m_termAmount->value();
+        // factor now is the duration in days. we divide this by the
+        // payment frequency and get the number of payments
+        factor /= m_wizard->m_generalLoanInfoPage->m_paymentFrequency->daysBetweenEvents();
+        break;
 
-    default:
-      qDebug("Unknown term unit %d in LoanDetailsPage::term(). Using payments.", m_termUnit->currentItem());
-      // tricky fall through here
+      default:
+        qDebug("Unknown term unit %d in LoanDetailsPage::term(). Using payments.", m_termUnit->currentItem());
+        // tricky fall through here
 
-    case MyMoneySchedule::OCCUR_ONCE: // payments
-      factor = m_termAmount->value();
-      break;
+      case MyMoneySchedule::OCCUR_ONCE: // payments
+        factor = m_termAmount->value();
+        break;
     }
   }
   return factor;
@@ -1109,18 +1120,18 @@ QString LoanDetailsPage::updateTermWidgets(const long double val)
   }
 
   switch (unit) {
-  case MyMoneySchedule::OCCUR_MONTHLY:
-    valString = i18np("one month", "%1 months", vl);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_MONTHLY);
-    break;
-  case MyMoneySchedule::OCCUR_YEARLY:
-    valString = i18np("one year", "%1 years", vl);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_YEARLY);
-    break;
-  default:
-    valString = i18np("one payment", "%1 payments", vl);
-    m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_ONCE);
-    break;
+    case MyMoneySchedule::OCCUR_MONTHLY:
+      valString = i18np("one month", "%1 months", vl);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_MONTHLY);
+      break;
+    case MyMoneySchedule::OCCUR_YEARLY:
+      valString = i18np("one year", "%1 years", vl);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_YEARLY);
+      break;
+    default:
+      valString = i18np("one payment", "%1 payments", vl);
+      m_termUnit->setCurrentItem(MyMoneySchedule::OCCUR_ONCE);
+      break;
   }
   m_termAmount->setValue(vl);
   return valString;
@@ -1636,7 +1647,7 @@ void AccountSummaryPage::enterPage(void)
     m_dataList->append(QString(i18nc("Schedule name", "Name") + ": %1").arg(sch.name()));
     if (acc.accountType() == MyMoneyAccount::CreditCard) {
       MyMoneyAccount paymentAccount = MyMoneyFile::instance()->account(m_wizard->m_schedulePage->m_paymentAccount->selectedItem());
-      m_dataList->append(QString(i18nc("Schedule occurrence", "Occurrence") + ": %1").arg(i18n("Monthly")));
+      m_dataList->append(QString(i18nc("Schedule occurrence", "Occurrence") + ": %1").arg(i18nc("Once per month schedule occurrence", "Monthly")));
       m_dataList->append(i18n("Paid from %1", paymentAccount.name()));
       m_dataList->append(i18n("Pay to %1", m_wizard->m_schedulePage->m_payee->currentText()));
       m_dataList->append(QString(i18n("Amount") + ": %1").arg(m_wizard->m_schedulePage->m_amount->value().formatMoney(acc, sec)));
